# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: milvus.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import common_pb2 as common__pb2
from . import schema_pb2 as schema__pb2
from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0cmilvus.proto\x12\x13milvus.proto.milvus\x1a\x0c\x63ommon.proto\x1a\x0cschema.proto\x1a google/protobuf/descriptor.proto\"y\n\x12\x43reateAliasRequest\x12*\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1c.milvus.proto.common.MsgBase\x12\x0f\n\x07\x64\x62_name\x18\x02 \x01(\t\x12\x17\n\x0f\x63ollection_name\x18\x03 \x01(\t\x12\r\n\x05\x61lias\x18\x04 \x01(\t\"^\n\x10\x44ropAliasRequest\x12*\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1c.milvus.proto.common.MsgBase\x12\x0f\n\x07\x64\x62_name\x18\x02 \x01(\t\x12\r\n\x05\x61lias\x18\x03 \x01(\t\"x\n\x11\x41lterAliasRequest\x12*\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1c.milvus.proto.common.MsgBase\x12\x0f\n\x07\x64\x62_name\x18\x02 \x01(\t\x12\x17\n\x0f\x63ollection_name\x18\x03 \x01(\t\x12\r\n\x05\x61lias\x18\x04 \x01(\t\"\xde\x01\n\x17\x43reateCollectionRequest\x12*\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1c.milvus.proto.common.MsgBase\x12\x0f\n\x07\x64\x62_name\x18\x02 \x01(\t\x12\x17\n\x0f\x63ollection_name\x18\x03 \x01(\t\x12\x0e\n\x06schema\x18\x04 \x01(\x0c\x12\x12\n\nshards_num\x18\x05 \x01(\x05\x12@\n\x11\x63onsistency_level\x18\x06 \x01(\x0e\x32%.milvus.proto.common.ConsistencyLevel:\x07\xca>\x04\x10\x01\x18\x03\"v\n\x15\x44ropCollectionRequest\x12*\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1c.milvus.proto.common.MsgBase\x12\x0f\n\x07\x64\x62_name\x18\x02 \x01(\t\x12\x17\n\x0f\x63ollection_name\x18\x03 \x01(\t:\x07\xca>\x04\x10\x02\x18\x03\"\x89\x01\n\x14HasCollectionRequest\x12*\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1c.milvus.proto.common.MsgBase\x12\x0f\n\x07\x64\x62_name\x18\x02 \x01(\t\x12\x17\n\x0f\x63ollection_name\x18\x03 \x01(\t\x12\x12\n\ntime_stamp\x18\x04 \x01(\x04:\x07\xca>\x04\x10\x04\x18\x03\"J\n\x0c\x42oolResponse\x12+\n\x06status\x18\x01 \x01(\x0b\x32\x1b.milvus.proto.common.Status\x12\r\n\x05value\x18\x02 \x01(\x08\"L\n\x0eStringResponse\x12+\n\x06status\x18\x01 \x01(\x0b\x32\x1b.milvus.proto.common.Status\x12\r\n\x05value\x18\x02 \x01(\t\"\xa4\x01\n\x19\x44\x65scribeCollectionRequest\x12*\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1c.milvus.proto.common.MsgBase\x12\x0f\n\x07\x64\x62_name\x18\x02 \x01(\t\x12\x17\n\x0f\x63ollection_name\x18\x03 \x01(\t\x12\x14\n\x0c\x63ollectionID\x18\x04 \x01(\x03\x12\x12\n\ntime_stamp\x18\x05 \x01(\x04:\x07\xca>\x04\x10\x04\x18\x03\"\xca\x03\n\x1a\x44\x65scribeCollectionResponse\x12+\n\x06status\x18\x01 \x01(\x0b\x32\x1b.milvus.proto.common.Status\x12\x35\n\x06schema\x18\x02 \x01(\x0b\x32%.milvus.proto.schema.CollectionSchema\x12\x14\n\x0c\x63ollectionID\x18\x03 \x01(\x03\x12\x1d\n\x15virtual_channel_names\x18\x04 \x03(\t\x12\x1e\n\x16physical_channel_names\x18\x05 \x03(\t\x12\x19\n\x11\x63reated_timestamp\x18\x06 \x01(\x04\x12\x1d\n\x15\x63reated_utc_timestamp\x18\x07 \x01(\x04\x12\x12\n\nshards_num\x18\x08 \x01(\x05\x12\x0f\n\x07\x61liases\x18\t \x03(\t\x12\x39\n\x0fstart_positions\x18\n \x03(\x0b\x32 .milvus.proto.common.KeyDataPair\x12@\n\x11\x63onsistency_level\x18\x0b \x01(\x0e\x32%.milvus.proto.common.ConsistencyLevel\x12\x17\n\x0f\x63ollection_name\x18\x0c \x01(\t\"\x8e\x01\n\x15LoadCollectionRequest\x12*\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1c.milvus.proto.common.MsgBase\x12\x0f\n\x07\x64\x62_name\x18\x02 \x01(\t\x12\x17\n\x0f\x63ollection_name\x18\x03 \x01(\t\x12\x16\n\x0ereplica_number\x18\x04 \x01(\x05:\x07\xca>\x04\x10\x05\x18\x03\"y\n\x18ReleaseCollectionRequest\x12*\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1c.milvus.proto.common.MsgBase\x12\x0f\n\x07\x64\x62_name\x18\x02 \x01(\t\x12\x17\n\x0f\x63ollection_name\x18\x03 \x01(\t:\x07\xca>\x04\x10\x06\x18\x03\"\x7f\n\x1eGetCollectionStatisticsRequest\x12*\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1c.milvus.proto.common.MsgBase\x12\x0f\n\x07\x64\x62_name\x18\x02 \x01(\t\x12\x17\n\x0f\x63ollection_name\x18\x03 \x01(\t:\x07\xca>\x04\x10\x04\x18\x03\"\x80\x01\n\x1fGetCollectionStatisticsResponse\x12+\n\x06status\x18\x01 \x01(\x0b\x32\x1b.milvus.proto.common.Status\x12\x30\n\x05stats\x18\x02 \x03(\x0b\x32!.milvus.proto.common.KeyValuePair\"\xb7\x01\n\x16ShowCollectionsRequest\x12*\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1c.milvus.proto.common.MsgBase\x12\x0f\n\x07\x64\x62_name\x18\x02 \x01(\t\x12\x12\n\ntime_stamp\x18\x03 \x01(\x04\x12+\n\x04type\x18\x04 \x01(\x0e\x32\x1d.milvus.proto.milvus.ShowType\x12\x18\n\x10\x63ollection_names\x18\x05 \x03(\t:\x05\xca>\x02\x10\x04\"\xf3\x01\n\x17ShowCollectionsResponse\x12+\n\x06status\x18\x01 \x01(\x0b\x32\x1b.milvus.proto.common.Status\x12\x18\n\x10\x63ollection_names\x18\x02 \x03(\t\x12\x16\n\x0e\x63ollection_ids\x18\x03 \x03(\x03\x12\x1a\n\x12\x63reated_timestamps\x18\x04 \x03(\x04\x12\x1e\n\x16\x63reated_utc_timestamps\x18\x05 \x03(\x04\x12\x1c\n\x14inMemory_percentages\x18\x06 \x03(\x03\x12\x1f\n\x17query_service_available\x18\x07 \x03(\x08\"\x86\x01\n\x16\x43reatePartitionRequest\x12*\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1c.milvus.proto.common.MsgBase\x12\x0f\n\x07\x64\x62_name\x18\x02 \x01(\t\x12\x17\n\x0f\x63ollection_name\x18\x03 \x01(\t\x12\x16\n\x0epartition_name\x18\x04 \x01(\t\"\x84\x01\n\x14\x44ropPartitionRequest\x12*\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1c.milvus.proto.common.MsgBase\x12\x0f\n\x07\x64\x62_name\x18\x02 \x01(\t\x12\x17\n\x0f\x63ollection_name\x18\x03 \x01(\t\x12\x16\n\x0epartition_name\x18\x04 \x01(\t\"\x83\x01\n\x13HasPartitionRequest\x12*\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1c.milvus.proto.common.MsgBase\x12\x0f\n\x07\x64\x62_name\x18\x02 \x01(\t\x12\x17\n\x0f\x63ollection_name\x18\x03 \x01(\t\x12\x16\n\x0epartition_name\x18\x04 \x01(\t\"\x9e\x01\n\x15LoadPartitionsRequest\x12*\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1c.milvus.proto.common.MsgBase\x12\x0f\n\x07\x64\x62_name\x18\x02 \x01(\t\x12\x17\n\x0f\x63ollection_name\x18\x03 \x01(\t\x12\x17\n\x0fpartition_names\x18\x04 \x03(\t\x12\x16\n\x0ereplica_number\x18\x05 \x01(\x05\"\x89\x01\n\x18ReleasePartitionsRequest\x12*\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1c.milvus.proto.common.MsgBase\x12\x0f\n\x07\x64\x62_name\x18\x02 \x01(\t\x12\x17\n\x0f\x63ollection_name\x18\x03 \x01(\t\x12\x17\n\x0fpartition_names\x18\x04 \x03(\t\"\x8d\x01\n\x1dGetPartitionStatisticsRequest\x12*\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1c.milvus.proto.common.MsgBase\x12\x0f\n\x07\x64\x62_name\x18\x02 \x01(\t\x12\x17\n\x0f\x63ollection_name\x18\x03 \x01(\t\x12\x16\n\x0epartition_name\x18\x04 \x01(\t\"\x7f\n\x1eGetPartitionStatisticsResponse\x12+\n\x06status\x18\x01 \x01(\x0b\x32\x1b.milvus.proto.common.Status\x12\x30\n\x05stats\x18\x02 \x03(\x0b\x32!.milvus.proto.common.KeyValuePair\"\xc9\x01\n\x15ShowPartitionsRequest\x12*\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1c.milvus.proto.common.MsgBase\x12\x0f\n\x07\x64\x62_name\x18\x02 \x01(\t\x12\x17\n\x0f\x63ollection_name\x18\x03 \x01(\t\x12\x14\n\x0c\x63ollectionID\x18\x04 \x01(\x03\x12\x17\n\x0fpartition_names\x18\x05 \x03(\t\x12+\n\x04type\x18\x06 \x01(\x0e\x32\x1d.milvus.proto.milvus.ShowType\"\xce\x01\n\x16ShowPartitionsResponse\x12+\n\x06status\x18\x01 \x01(\x0b\x32\x1b.milvus.proto.common.Status\x12\x17\n\x0fpartition_names\x18\x02 \x03(\t\x12\x14\n\x0cpartitionIDs\x18\x03 \x03(\x03\x12\x1a\n\x12\x63reated_timestamps\x18\x04 \x03(\x04\x12\x1e\n\x16\x63reated_utc_timestamps\x18\x05 \x03(\x04\x12\x1c\n\x14inMemory_percentages\x18\x06 \x03(\x03\"m\n\x16\x44\x65scribeSegmentRequest\x12*\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1c.milvus.proto.common.MsgBase\x12\x14\n\x0c\x63ollectionID\x18\x02 \x01(\x03\x12\x11\n\tsegmentID\x18\x03 \x01(\x03\"\x8f\x01\n\x17\x44\x65scribeSegmentResponse\x12+\n\x06status\x18\x01 \x01(\x0b\x32\x1b.milvus.proto.common.Status\x12\x0f\n\x07indexID\x18\x02 \x01(\x03\x12\x0f\n\x07\x62uildID\x18\x03 \x01(\x03\x12\x14\n\x0c\x65nable_index\x18\x04 \x01(\x08\x12\x0f\n\x07\x66ieldID\x18\x05 \x01(\x03\"l\n\x13ShowSegmentsRequest\x12*\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1c.milvus.proto.common.MsgBase\x12\x14\n\x0c\x63ollectionID\x18\x02 \x01(\x03\x12\x13\n\x0bpartitionID\x18\x03 \x01(\x03\"W\n\x14ShowSegmentsResponse\x12+\n\x06status\x18\x01 \x01(\x0b\x32\x1b.milvus.proto.common.Status\x12\x12\n\nsegmentIDs\x18\x02 \x03(\x03\"\xcb\x01\n\x12\x43reateIndexRequest\x12*\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1c.milvus.proto.common.MsgBase\x12\x0f\n\x07\x64\x62_name\x18\x02 \x01(\t\x12\x17\n\x0f\x63ollection_name\x18\x03 \x01(\t\x12\x12\n\nfield_name\x18\x04 \x01(\t\x12\x37\n\x0c\x65xtra_params\x18\x05 \x03(\x0b\x32!.milvus.proto.common.KeyValuePair\x12\x12\n\nindex_name\x18\x06 \x01(\t\"\x94\x01\n\x14\x44\x65scribeIndexRequest\x12*\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1c.milvus.proto.common.MsgBase\x12\x0f\n\x07\x64\x62_name\x18\x02 \x01(\t\x12\x17\n\x0f\x63ollection_name\x18\x03 \x01(\t\x12\x12\n\nfield_name\x18\x04 \x01(\t\x12\x12\n\nindex_name\x18\x05 \x01(\t\"~\n\x10IndexDescription\x12\x12\n\nindex_name\x18\x01 \x01(\t\x12\x0f\n\x07indexID\x18\x02 \x01(\x03\x12\x31\n\x06params\x18\x03 \x03(\x0b\x32!.milvus.proto.common.KeyValuePair\x12\x12\n\nfield_name\x18\x04 \x01(\t\"\x87\x01\n\x15\x44\x65scribeIndexResponse\x12+\n\x06status\x18\x01 \x01(\x0b\x32\x1b.milvus.proto.common.Status\x12\x41\n\x12index_descriptions\x18\x02 \x03(\x0b\x32%.milvus.proto.milvus.IndexDescription\"\x9c\x01\n\x1cGetIndexBuildProgressRequest\x12*\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1c.milvus.proto.common.MsgBase\x12\x0f\n\x07\x64\x62_name\x18\x02 \x01(\t\x12\x17\n\x0f\x63ollection_name\x18\x03 \x01(\t\x12\x12\n\nfield_name\x18\x04 \x01(\t\x12\x12\n\nindex_name\x18\x05 \x01(\t\"v\n\x1dGetIndexBuildProgressResponse\x12+\n\x06status\x18\x01 \x01(\x0b\x32\x1b.milvus.proto.common.Status\x12\x14\n\x0cindexed_rows\x18\x02 \x01(\x03\x12\x12\n\ntotal_rows\x18\x03 \x01(\x03\"\x94\x01\n\x14GetIndexStateRequest\x12*\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1c.milvus.proto.common.MsgBase\x12\x0f\n\x07\x64\x62_name\x18\x02 \x01(\t\x12\x17\n\x0f\x63ollection_name\x18\x03 \x01(\t\x12\x12\n\nfield_name\x18\x04 \x01(\t\x12\x12\n\nindex_name\x18\x05 \x01(\t\"\x89\x01\n\x15GetIndexStateResponse\x12+\n\x06status\x18\x01 \x01(\x0b\x32\x1b.milvus.proto.common.Status\x12.\n\x05state\x18\x02 \x01(\x0e\x32\x1f.milvus.proto.common.IndexState\x12\x13\n\x0b\x66\x61il_reason\x18\x03 \x01(\t\"\x90\x01\n\x10\x44ropIndexRequest\x12*\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1c.milvus.proto.common.MsgBase\x12\x0f\n\x07\x64\x62_name\x18\x02 \x01(\t\x12\x17\n\x0f\x63ollection_name\x18\x03 \x01(\t\x12\x12\n\nfield_name\x18\x04 \x01(\t\x12\x12\n\nindex_name\x18\x05 \x01(\t\"\xd7\x01\n\rInsertRequest\x12*\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1c.milvus.proto.common.MsgBase\x12\x0f\n\x07\x64\x62_name\x18\x02 \x01(\t\x12\x17\n\x0f\x63ollection_name\x18\x03 \x01(\t\x12\x16\n\x0epartition_name\x18\x04 \x01(\t\x12\x33\n\x0b\x66ields_data\x18\x05 \x03(\x0b\x32\x1e.milvus.proto.schema.FieldData\x12\x11\n\thash_keys\x18\x06 \x03(\r\x12\x10\n\x08num_rows\x18\x07 \x01(\r\"\xf0\x01\n\x0eMutationResult\x12+\n\x06status\x18\x01 \x01(\x0b\x32\x1b.milvus.proto.common.Status\x12%\n\x03IDs\x18\x02 \x01(\x0b\x32\x18.milvus.proto.schema.IDs\x12\x12\n\nsucc_index\x18\x03 \x03(\r\x12\x11\n\terr_index\x18\x04 \x03(\r\x12\x14\n\x0c\x61\x63knowledged\x18\x05 \x01(\x08\x12\x12\n\ninsert_cnt\x18\x06 \x01(\x03\x12\x12\n\ndelete_cnt\x18\x07 \x01(\x03\x12\x12\n\nupsert_cnt\x18\x08 \x01(\x03\x12\x11\n\ttimestamp\x18\t \x01(\x04\"\x9e\x01\n\rDeleteRequest\x12*\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1c.milvus.proto.common.MsgBase\x12\x0f\n\x07\x64\x62_name\x18\x02 \x01(\t\x12\x17\n\x0f\x63ollection_name\x18\x03 \x01(\t\x12\x16\n\x0epartition_name\x18\x04 \x01(\t\x12\x0c\n\x04\x65xpr\x18\x05 \x01(\t\x12\x11\n\thash_keys\x18\x06 \x03(\r\"\xea\x02\n\rSearchRequest\x12*\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1c.milvus.proto.common.MsgBase\x12\x0f\n\x07\x64\x62_name\x18\x02 \x01(\t\x12\x17\n\x0f\x63ollection_name\x18\x03 \x01(\t\x12\x17\n\x0fpartition_names\x18\x04 \x03(\t\x12\x0b\n\x03\x64sl\x18\x05 \x01(\t\x12\x19\n\x11placeholder_group\x18\x06 \x01(\x0c\x12.\n\x08\x64sl_type\x18\x07 \x01(\x0e\x32\x1c.milvus.proto.common.DslType\x12\x15\n\routput_fields\x18\x08 \x03(\t\x12\x38\n\rsearch_params\x18\t \x03(\x0b\x32!.milvus.proto.common.KeyValuePair\x12\x18\n\x10travel_timestamp\x18\n \x01(\x04\x12\x1b\n\x13guarantee_timestamp\x18\x0b \x01(\x04\x12\n\n\x02nq\x18\x0c \x01(\x03\"5\n\x04Hits\x12\x0b\n\x03IDs\x18\x01 \x03(\x03\x12\x10\n\x08row_data\x18\x02 \x03(\x0c\x12\x0e\n\x06scores\x18\x03 \x03(\x02\"\x8d\x01\n\rSearchResults\x12+\n\x06status\x18\x01 \x01(\x0b\x32\x1b.milvus.proto.common.Status\x12\x36\n\x07results\x18\x02 \x01(\x0b\x32%.milvus.proto.schema.SearchResultData\x12\x17\n\x0f\x63ollection_name\x18\x03 \x01(\t\"e\n\x0c\x46lushRequest\x12*\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1c.milvus.proto.common.MsgBase\x12\x0f\n\x07\x64\x62_name\x18\x02 \x01(\t\x12\x18\n\x10\x63ollection_names\x18\x03 \x03(\t\"\xe9\x01\n\rFlushResponse\x12+\n\x06status\x18\x01 \x01(\x0b\x32\x1b.milvus.proto.common.Status\x12\x0f\n\x07\x64\x62_name\x18\x02 \x01(\t\x12G\n\x0b\x63oll_segIDs\x18\x03 \x03(\x0b\x32\x32.milvus.proto.milvus.FlushResponse.CollSegIDsEntry\x1aQ\n\x0f\x43ollSegIDsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12-\n\x05value\x18\x02 \x01(\x0b\x32\x1e.milvus.proto.schema.LongArray:\x02\x38\x01\"\xd9\x01\n\x0cQueryRequest\x12*\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1c.milvus.proto.common.MsgBase\x12\x0f\n\x07\x64\x62_name\x18\x02 \x01(\t\x12\x17\n\x0f\x63ollection_name\x18\x03 \x01(\t\x12\x0c\n\x04\x65xpr\x18\x04 \x01(\t\x12\x15\n\routput_fields\x18\x05 \x03(\t\x12\x17\n\x0fpartition_names\x18\x06 \x03(\t\x12\x18\n\x10travel_timestamp\x18\x07 \x01(\x04\x12\x1b\n\x13guarantee_timestamp\x18\x08 \x01(\x04\"\x89\x01\n\x0cQueryResults\x12+\n\x06status\x18\x01 \x01(\x0b\x32\x1b.milvus.proto.common.Status\x12\x33\n\x0b\x66ields_data\x18\x02 \x03(\x0b\x32\x1e.milvus.proto.schema.FieldData\x12\x17\n\x0f\x63ollection_name\x18\x03 \x01(\t\"}\n\tVectorIDs\x12\x17\n\x0f\x63ollection_name\x18\x01 \x01(\t\x12\x12\n\nfield_name\x18\x02 \x01(\t\x12*\n\x08id_array\x18\x03 \x01(\x0b\x32\x18.milvus.proto.schema.IDs\x12\x17\n\x0fpartition_names\x18\x04 \x03(\t\"\x83\x01\n\x0cVectorsArray\x12\x32\n\x08id_array\x18\x01 \x01(\x0b\x32\x1e.milvus.proto.milvus.VectorIDsH\x00\x12\x36\n\ndata_array\x18\x02 \x01(\x0b\x32 .milvus.proto.schema.VectorFieldH\x00\x42\x07\n\x05\x61rray\"\xdd\x01\n\x13\x43\x61lcDistanceRequest\x12*\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1c.milvus.proto.common.MsgBase\x12\x32\n\x07op_left\x18\x02 \x01(\x0b\x32!.milvus.proto.milvus.VectorsArray\x12\x33\n\x08op_right\x18\x03 \x01(\x0b\x32!.milvus.proto.milvus.VectorsArray\x12\x31\n\x06params\x18\x04 \x03(\x0b\x32!.milvus.proto.common.KeyValuePair\"\xb5\x01\n\x13\x43\x61lcDistanceResults\x12+\n\x06status\x18\x01 \x01(\x0b\x32\x1b.milvus.proto.common.Status\x12\x31\n\x08int_dist\x18\x02 \x01(\x0b\x32\x1d.milvus.proto.schema.IntArrayH\x00\x12\x35\n\nfloat_dist\x18\x03 \x01(\x0b\x32\x1f.milvus.proto.schema.FloatArrayH\x00\x42\x07\n\x05\x61rray\"\x99\x01\n\x15PersistentSegmentInfo\x12\x11\n\tsegmentID\x18\x01 \x01(\x03\x12\x14\n\x0c\x63ollectionID\x18\x02 \x01(\x03\x12\x13\n\x0bpartitionID\x18\x03 \x01(\x03\x12\x10\n\x08num_rows\x18\x04 \x01(\x03\x12\x30\n\x05state\x18\x05 \x01(\x0e\x32!.milvus.proto.common.SegmentState\"u\n\x1fGetPersistentSegmentInfoRequest\x12*\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1c.milvus.proto.common.MsgBase\x12\x0e\n\x06\x64\x62Name\x18\x02 \x01(\t\x12\x16\n\x0e\x63ollectionName\x18\x03 \x01(\t\"\x8a\x01\n GetPersistentSegmentInfoResponse\x12+\n\x06status\x18\x01 \x01(\x0b\x32\x1b.milvus.proto.common.Status\x12\x39\n\x05infos\x18\x02 \x03(\x0b\x32*.milvus.proto.milvus.PersistentSegmentInfo\"\xec\x01\n\x10QuerySegmentInfo\x12\x11\n\tsegmentID\x18\x01 \x01(\x03\x12\x14\n\x0c\x63ollectionID\x18\x02 \x01(\x03\x12\x13\n\x0bpartitionID\x18\x03 \x01(\x03\x12\x10\n\x08mem_size\x18\x04 \x01(\x03\x12\x10\n\x08num_rows\x18\x05 \x01(\x03\x12\x12\n\nindex_name\x18\x06 \x01(\t\x12\x0f\n\x07indexID\x18\x07 \x01(\x03\x12\x0e\n\x06nodeID\x18\x08 \x01(\x03\x12\x30\n\x05state\x18\t \x01(\x0e\x32!.milvus.proto.common.SegmentState\x12\x0f\n\x07nodeIds\x18\n \x03(\x03\"p\n\x1aGetQuerySegmentInfoRequest\x12*\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1c.milvus.proto.common.MsgBase\x12\x0e\n\x06\x64\x62Name\x18\x02 \x01(\t\x12\x16\n\x0e\x63ollectionName\x18\x03 \x01(\t\"\x80\x01\n\x1bGetQuerySegmentInfoResponse\x12+\n\x06status\x18\x01 \x01(\x0b\x32\x1b.milvus.proto.common.Status\x12\x34\n\x05infos\x18\x02 \x03(\x0b\x32%.milvus.proto.milvus.QuerySegmentInfo\"$\n\x0c\x44ummyRequest\x12\x14\n\x0crequest_type\x18\x01 \x01(\t\"!\n\rDummyResponse\x12\x10\n\x08response\x18\x01 \x01(\t\"\x15\n\x13RegisterLinkRequest\"r\n\x14RegisterLinkResponse\x12-\n\x07\x61\x64\x64ress\x18\x01 \x01(\x0b\x32\x1c.milvus.proto.common.Address\x12+\n\x06status\x18\x02 \x01(\x0b\x32\x1b.milvus.proto.common.Status\"P\n\x11GetMetricsRequest\x12*\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1c.milvus.proto.common.MsgBase\x12\x0f\n\x07request\x18\x02 \x01(\t\"k\n\x12GetMetricsResponse\x12+\n\x06status\x18\x01 \x01(\x0b\x32\x1b.milvus.proto.common.Status\x12\x10\n\x08response\x18\x02 \x01(\t\x12\x16\n\x0e\x63omponent_name\x18\x03 \x01(\t\"\x9c\x01\n\x12LoadBalanceRequest\x12*\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1c.milvus.proto.common.MsgBase\x12\x12\n\nsrc_nodeID\x18\x02 \x01(\x03\x12\x13\n\x0b\x64st_nodeIDs\x18\x03 \x03(\x03\x12\x19\n\x11sealed_segmentIDs\x18\x04 \x03(\x03\x12\x16\n\x0e\x63ollectionName\x18\x05 \x01(\t\"C\n\x17ManualCompactionRequest\x12\x14\n\x0c\x63ollectionID\x18\x01 \x01(\x03\x12\x12\n\ntimetravel\x18\x02 \x01(\x04\"]\n\x18ManualCompactionResponse\x12+\n\x06status\x18\x01 \x01(\x0b\x32\x1b.milvus.proto.common.Status\x12\x14\n\x0c\x63ompactionID\x18\x02 \x01(\x03\"1\n\x19GetCompactionStateRequest\x12\x14\n\x0c\x63ompactionID\x18\x01 \x01(\x03\"\xc7\x01\n\x1aGetCompactionStateResponse\x12+\n\x06status\x18\x01 \x01(\x0b\x32\x1b.milvus.proto.common.Status\x12\x33\n\x05state\x18\x02 \x01(\x0e\x32$.milvus.proto.common.CompactionState\x12\x17\n\x0f\x65xecutingPlanNo\x18\x03 \x01(\x03\x12\x15\n\rtimeoutPlanNo\x18\x04 \x01(\x03\x12\x17\n\x0f\x63ompletedPlanNo\x18\x05 \x01(\x03\"1\n\x19GetCompactionPlansRequest\x12\x14\n\x0c\x63ompactionID\x18\x01 \x01(\x03\"\xbc\x01\n\x1aGetCompactionPlansResponse\x12+\n\x06status\x18\x01 \x01(\x0b\x32\x1b.milvus.proto.common.Status\x12\x33\n\x05state\x18\x02 \x01(\x0e\x32$.milvus.proto.common.CompactionState\x12<\n\nmergeInfos\x18\x03 \x03(\x0b\x32(.milvus.proto.milvus.CompactionMergeInfo\"6\n\x13\x43ompactionMergeInfo\x12\x0f\n\x07sources\x18\x01 \x03(\x03\x12\x0e\n\x06target\x18\x02 \x01(\x03\"*\n\x14GetFlushStateRequest\x12\x12\n\nsegmentIDs\x18\x01 \x03(\x03\"U\n\x15GetFlushStateResponse\x12+\n\x06status\x18\x01 \x01(\x0b\x32\x1b.milvus.proto.common.Status\x12\x0f\n\x07\x66lushed\x18\x02 \x01(\x08\"\xad\x01\n\rImportRequest\x12\x17\n\x0f\x63ollection_name\x18\x01 \x01(\t\x12\x16\n\x0epartition_name\x18\x02 \x01(\t\x12\x15\n\rchannel_names\x18\x03 \x03(\t\x12\x11\n\trow_based\x18\x04 \x01(\x08\x12\r\n\x05\x66iles\x18\x05 \x03(\t\x12\x32\n\x07options\x18\x06 \x03(\x0b\x32!.milvus.proto.common.KeyValuePair\"L\n\x0eImportResponse\x12+\n\x06status\x18\x01 \x01(\x0b\x32\x1b.milvus.proto.common.Status\x12\r\n\x05tasks\x18\x02 \x03(\x03\"%\n\x15GetImportStateRequest\x12\x0c\n\x04task\x18\x01 \x01(\x03\"\x86\x02\n\x16GetImportStateResponse\x12+\n\x06status\x18\x01 \x01(\x0b\x32\x1b.milvus.proto.common.Status\x12/\n\x05state\x18\x02 \x01(\x0e\x32 .milvus.proto.common.ImportState\x12\x11\n\trow_count\x18\x03 \x01(\x03\x12\x0f\n\x07id_list\x18\x04 \x03(\x03\x12\x30\n\x05infos\x18\x05 \x03(\x0b\x32!.milvus.proto.common.KeyValuePair\x12\n\n\x02id\x18\x06 \x01(\x03\x12\x16\n\x0e\x64\x61ta_queryable\x18\x07 \x01(\x08\x12\x14\n\x0c\x64\x61ta_indexed\x18\x08 \x01(\x08\"\x18\n\x16ListImportTasksRequest\"\x82\x01\n\x17ListImportTasksResponse\x12+\n\x06status\x18\x01 \x01(\x0b\x32\x1b.milvus.proto.common.Status\x12:\n\x05tasks\x18\x02 \x03(\x0b\x32+.milvus.proto.milvus.GetImportStateResponse\"p\n\x12GetReplicasRequest\x12*\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1c.milvus.proto.common.MsgBase\x12\x14\n\x0c\x63ollectionID\x18\x02 \x01(\x03\x12\x18\n\x10with_shard_nodes\x18\x03 \x01(\x08\"v\n\x13GetReplicasResponse\x12+\n\x06status\x18\x01 \x01(\x0b\x32\x1b.milvus.proto.common.Status\x12\x32\n\x08replicas\x18\x02 \x03(\x0b\x32 .milvus.proto.milvus.ReplicaInfo\"\x9a\x01\n\x0bReplicaInfo\x12\x11\n\treplicaID\x18\x01 \x01(\x03\x12\x14\n\x0c\x63ollectionID\x18\x02 \x01(\x03\x12\x15\n\rpartition_ids\x18\x03 \x03(\x03\x12\x39\n\x0eshard_replicas\x18\x04 \x03(\x0b\x32!.milvus.proto.milvus.ShardReplica\x12\x10\n\x08node_ids\x18\x05 \x03(\x03\"`\n\x0cShardReplica\x12\x10\n\x08leaderID\x18\x01 \x01(\x03\x12\x13\n\x0bleader_addr\x18\x02 \x01(\t\x12\x17\n\x0f\x64m_channel_name\x18\x03 \x01(\t\x12\x10\n\x08node_ids\x18\x04 \x03(\x03\"\xaa\x01\n\x17\x43reateCredentialRequest\x12*\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1c.milvus.proto.common.MsgBase\x12\x10\n\x08username\x18\x02 \x01(\t\x12\x10\n\x08password\x18\x03 \x01(\t\x12\x1e\n\x16\x63reated_utc_timestamps\x18\x04 \x01(\x04\x12\x1f\n\x17modified_utc_timestamps\x18\x05 \x01(\x04\"\xc2\x01\n\x17UpdateCredentialRequest\x12*\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1c.milvus.proto.common.MsgBase\x12\x10\n\x08username\x18\x02 \x01(\t\x12\x13\n\x0boldPassword\x18\x03 \x01(\t\x12\x13\n\x0bnewPassword\x18\x04 \x01(\t\x12\x1e\n\x16\x63reated_utc_timestamps\x18\x05 \x01(\x04\x12\x1f\n\x17modified_utc_timestamps\x18\x06 \x01(\x04\"W\n\x17\x44\x65leteCredentialRequest\x12*\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1c.milvus.proto.common.MsgBase\x12\x10\n\x08username\x18\x02 \x01(\t\"W\n\x15ListCredUsersResponse\x12+\n\x06status\x18\x01 \x01(\x0b\x32\x1b.milvus.proto.common.Status\x12\x11\n\tusernames\x18\x02 \x03(\t\"B\n\x14ListCredUsersRequest\x12*\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1c.milvus.proto.common.MsgBase\"\x1a\n\nRoleEntity\x12\x0c\n\x04name\x18\x01 \x01(\t\"\x1a\n\nUserEntity\x12\x0c\n\x04name\x18\x01 \x01(\t\"p\n\x11\x43reateRoleRequest\x12*\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1c.milvus.proto.common.MsgBase\x12/\n\x06\x65ntity\x18\x02 \x01(\x0b\x32\x1f.milvus.proto.milvus.RoleEntity\"P\n\x0f\x44ropRoleRequest\x12*\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1c.milvus.proto.common.MsgBase\x12\x11\n\trole_name\x18\x02 \x01(\t\"\xa1\x01\n\x16OperateUserRoleRequest\x12*\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1c.milvus.proto.common.MsgBase\x12\x10\n\x08username\x18\x02 \x01(\t\x12\x11\n\trole_name\x18\x03 \x01(\t\x12\x36\n\x04type\x18\x04 \x01(\x0e\x32(.milvus.proto.milvus.OperateUserRoleType\"\x89\x01\n\x11SelectRoleRequest\x12*\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1c.milvus.proto.common.MsgBase\x12-\n\x04role\x18\x02 \x01(\x0b\x32\x1f.milvus.proto.milvus.RoleEntity\x12\x19\n\x11include_user_info\x18\x03 \x01(\x08\"k\n\nRoleResult\x12-\n\x04role\x18\x01 \x01(\x0b\x32\x1f.milvus.proto.milvus.RoleEntity\x12.\n\x05users\x18\x02 \x03(\x0b\x32\x1f.milvus.proto.milvus.UserEntity\"s\n\x12SelectRoleResponse\x12+\n\x06status\x18\x01 \x01(\x0b\x32\x1b.milvus.proto.common.Status\x12\x30\n\x07results\x18\x02 \x03(\x0b\x32\x1f.milvus.proto.milvus.RoleResult\"\x89\x01\n\x11SelectUserRequest\x12*\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1c.milvus.proto.common.MsgBase\x12-\n\x04user\x18\x02 \x01(\x0b\x32\x1f.milvus.proto.milvus.UserEntity\x12\x19\n\x11include_role_info\x18\x03 \x01(\x08\"k\n\nUserResult\x12-\n\x04user\x18\x01 \x01(\x0b\x32\x1f.milvus.proto.milvus.UserEntity\x12.\n\x05roles\x18\x02 \x03(\x0b\x32\x1f.milvus.proto.milvus.RoleEntity\"r\n\x12SelectUserResponse\x12+\n\x06status\x18\x01 \x01(\x0b\x32\x1b.milvus.proto.common.Status\x12/\n\x06result\x18\x02 \x03(\x0b\x32\x1f.milvus.proto.milvus.UserResult\"\x1e\n\x0eResourceEntity\x12\x0c\n\x04type\x18\x01 \x01(\t\"\x1f\n\x0fPrivilegeEntity\x12\x0c\n\x04name\x18\x01 \x01(\t\"\x98\x01\n\x15SelectResourceRequest\x12*\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1c.milvus.proto.common.MsgBase\x12\x33\n\x06\x65ntity\x18\x02 \x01(\x0b\x32#.milvus.proto.milvus.ResourceEntity\x12\x1e\n\x16include_privilege_info\x18\x03 \x01(\x08\"\x81\x01\n\x0eResourceResult\x12\x35\n\x08resource\x18\x01 \x01(\x0b\x32#.milvus.proto.milvus.ResourceEntity\x12\x38\n\nprivileges\x18\x02 \x03(\x0b\x32$.milvus.proto.milvus.PrivilegeEntity\"{\n\x16SelectResourceResponse\x12+\n\x06status\x18\x01 \x01(\x0b\x32\x1b.milvus.proto.common.Status\x12\x34\n\x07results\x18\x02 \x03(\x0b\x32#.milvus.proto.milvus.ResourceResult\"\x98\x01\n\x0fPrincipalEntity\x12\x16\n\x0eprincipal_type\x18\x01 \x01(\t\x12/\n\x04user\x18\x02 \x01(\x0b\x32\x1f.milvus.proto.milvus.UserEntityH\x00\x12/\n\x04role\x18\x03 \x01(\x0b\x32\x1f.milvus.proto.milvus.RoleEntityH\x00\x42\x0b\n\tprincipal\"w\n\rGrantorEntity\x12-\n\x04user\x18\x01 \x01(\x0b\x32\x1f.milvus.proto.milvus.UserEntity\x12\x37\n\tprivilege\x18\x02 \x01(\x0b\x32$.milvus.proto.milvus.PrivilegeEntity\"\xc9\x01\n\x0bGrantEntity\x12\x37\n\tprincipal\x18\x01 \x01(\x0b\x32$.milvus.proto.milvus.PrincipalEntity\x12\x35\n\x08resource\x18\x02 \x01(\x0b\x32#.milvus.proto.milvus.ResourceEntity\x12\x15\n\rresource_name\x18\x03 \x01(\t\x12\x33\n\x07grantor\x18\x04 \x01(\x0b\x32\".milvus.proto.milvus.GrantorEntity\"r\n\x12SelectGrantRequest\x12*\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1c.milvus.proto.common.MsgBase\x12\x30\n\x06\x65ntity\x18\x02 \x01(\x0b\x32 .milvus.proto.milvus.GrantEntity\"v\n\x13SelectGrantResponse\x12+\n\x06status\x18\x01 \x01(\x0b\x32\x1b.milvus.proto.common.Status\x12\x32\n\x08\x65ntities\x18\x02 \x03(\x0b\x32 .milvus.proto.milvus.GrantEntity\"\xb0\x01\n\x17OperatePrivilegeRequest\x12*\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1c.milvus.proto.common.MsgBase\x12\x30\n\x06\x65ntity\x18\x02 \x01(\x0b\x32 .milvus.proto.milvus.GrantEntity\x12\x37\n\x04type\x18\x03 \x01(\x0e\x32).milvus.proto.milvus.OperatePrivilegeType\"\x1c\n\tMilvusExt\x12\x0f\n\x07version\x18\x01 \x01(\t*!\n\x08ShowType\x12\x07\n\x03\x41ll\x10\x00\x12\x0c\n\x08InMemory\x10\x01*@\n\x13OperateUserRoleType\x12\x11\n\rAddUserToRole\x10\x00\x12\x16\n\x12RemoveUserFromRole\x10\x01*-\n\x14OperatePrivilegeType\x12\t\n\x05Grant\x10\x00\x12\n\n\x06Revoke\x10\x01\x32\xa1+\n\rMilvusService\x12_\n\x10\x43reateCollection\x12,.milvus.proto.milvus.CreateCollectionRequest\x1a\x1b.milvus.proto.common.Status\"\x00\x12[\n\x0e\x44ropCollection\x12*.milvus.proto.milvus.DropCollectionRequest\x1a\x1b.milvus.proto.common.Status\"\x00\x12_\n\rHasCollection\x12).milvus.proto.milvus.HasCollectionRequest\x1a!.milvus.proto.milvus.BoolResponse\"\x00\x12[\n\x0eLoadCollection\x12*.milvus.proto.milvus.LoadCollectionRequest\x1a\x1b.milvus.proto.common.Status\"\x00\x12\x61\n\x11ReleaseCollection\x12-.milvus.proto.milvus.ReleaseCollectionRequest\x1a\x1b.milvus.proto.common.Status\"\x00\x12w\n\x12\x44\x65scribeCollection\x12..milvus.proto.milvus.DescribeCollectionRequest\x1a/.milvus.proto.milvus.DescribeCollectionResponse\"\x00\x12\x86\x01\n\x17GetCollectionStatistics\x12\x33.milvus.proto.milvus.GetCollectionStatisticsRequest\x1a\x34.milvus.proto.milvus.GetCollectionStatisticsResponse\"\x00\x12n\n\x0fShowCollections\x12+.milvus.proto.milvus.ShowCollectionsRequest\x1a,.milvus.proto.milvus.ShowCollectionsResponse\"\x00\x12]\n\x0f\x43reatePartition\x12+.milvus.proto.milvus.CreatePartitionRequest\x1a\x1b.milvus.proto.common.Status\"\x00\x12Y\n\rDropPartition\x12).milvus.proto.milvus.DropPartitionRequest\x1a\x1b.milvus.proto.common.Status\"\x00\x12]\n\x0cHasPartition\x12(.milvus.proto.milvus.HasPartitionRequest\x1a!.milvus.proto.milvus.BoolResponse\"\x00\x12[\n\x0eLoadPartitions\x12*.milvus.proto.milvus.LoadPartitionsRequest\x1a\x1b.milvus.proto.common.Status\"\x00\x12\x61\n\x11ReleasePartitions\x12-.milvus.proto.milvus.ReleasePartitionsRequest\x1a\x1b.milvus.proto.common.Status\"\x00\x12\x83\x01\n\x16GetPartitionStatistics\x12\x32.milvus.proto.milvus.GetPartitionStatisticsRequest\x1a\x33.milvus.proto.milvus.GetPartitionStatisticsResponse\"\x00\x12k\n\x0eShowPartitions\x12*.milvus.proto.milvus.ShowPartitionsRequest\x1a+.milvus.proto.milvus.ShowPartitionsResponse\"\x00\x12U\n\x0b\x43reateAlias\x12\'.milvus.proto.milvus.CreateAliasRequest\x1a\x1b.milvus.proto.common.Status\"\x00\x12Q\n\tDropAlias\x12%.milvus.proto.milvus.DropAliasRequest\x1a\x1b.milvus.proto.common.Status\"\x00\x12S\n\nAlterAlias\x12&.milvus.proto.milvus.AlterAliasRequest\x1a\x1b.milvus.proto.common.Status\"\x00\x12U\n\x0b\x43reateIndex\x12\'.milvus.proto.milvus.CreateIndexRequest\x1a\x1b.milvus.proto.common.Status\"\x00\x12h\n\rDescribeIndex\x12).milvus.proto.milvus.DescribeIndexRequest\x1a*.milvus.proto.milvus.DescribeIndexResponse\"\x00\x12h\n\rGetIndexState\x12).milvus.proto.milvus.GetIndexStateRequest\x1a*.milvus.proto.milvus.GetIndexStateResponse\"\x00\x12\x80\x01\n\x15GetIndexBuildProgress\x12\x31.milvus.proto.milvus.GetIndexBuildProgressRequest\x1a\x32.milvus.proto.milvus.GetIndexBuildProgressResponse\"\x00\x12Q\n\tDropIndex\x12%.milvus.proto.milvus.DropIndexRequest\x1a\x1b.milvus.proto.common.Status\"\x00\x12S\n\x06Insert\x12\".milvus.proto.milvus.InsertRequest\x1a#.milvus.proto.milvus.MutationResult\"\x00\x12S\n\x06\x44\x65lete\x12\".milvus.proto.milvus.DeleteRequest\x1a#.milvus.proto.milvus.MutationResult\"\x00\x12R\n\x06Search\x12\".milvus.proto.milvus.SearchRequest\x1a\".milvus.proto.milvus.SearchResults\"\x00\x12P\n\x05\x46lush\x12!.milvus.proto.milvus.FlushRequest\x1a\".milvus.proto.milvus.FlushResponse\"\x00\x12O\n\x05Query\x12!.milvus.proto.milvus.QueryRequest\x1a!.milvus.proto.milvus.QueryResults\"\x00\x12\x64\n\x0c\x43\x61lcDistance\x12(.milvus.proto.milvus.CalcDistanceRequest\x1a(.milvus.proto.milvus.CalcDistanceResults\"\x00\x12h\n\rGetFlushState\x12).milvus.proto.milvus.GetFlushStateRequest\x1a*.milvus.proto.milvus.GetFlushStateResponse\"\x00\x12\x89\x01\n\x18GetPersistentSegmentInfo\x12\x34.milvus.proto.milvus.GetPersistentSegmentInfoRequest\x1a\x35.milvus.proto.milvus.GetPersistentSegmentInfoResponse\"\x00\x12z\n\x13GetQuerySegmentInfo\x12/.milvus.proto.milvus.GetQuerySegmentInfoRequest\x1a\x30.milvus.proto.milvus.GetQuerySegmentInfoResponse\"\x00\x12\x62\n\x0bGetReplicas\x12\'.milvus.proto.milvus.GetReplicasRequest\x1a(.milvus.proto.milvus.GetReplicasResponse\"\x00\x12P\n\x05\x44ummy\x12!.milvus.proto.milvus.DummyRequest\x1a\".milvus.proto.milvus.DummyResponse\"\x00\x12\x65\n\x0cRegisterLink\x12(.milvus.proto.milvus.RegisterLinkRequest\x1a).milvus.proto.milvus.RegisterLinkResponse\"\x00\x12_\n\nGetMetrics\x12&.milvus.proto.milvus.GetMetricsRequest\x1a\'.milvus.proto.milvus.GetMetricsResponse\"\x00\x12U\n\x0bLoadBalance\x12\'.milvus.proto.milvus.LoadBalanceRequest\x1a\x1b.milvus.proto.common.Status\"\x00\x12w\n\x12GetCompactionState\x12..milvus.proto.milvus.GetCompactionStateRequest\x1a/.milvus.proto.milvus.GetCompactionStateResponse\"\x00\x12q\n\x10ManualCompaction\x12,.milvus.proto.milvus.ManualCompactionRequest\x1a-.milvus.proto.milvus.ManualCompactionResponse\"\x00\x12\x80\x01\n\x1bGetCompactionStateWithPlans\x12..milvus.proto.milvus.GetCompactionPlansRequest\x1a/.milvus.proto.milvus.GetCompactionPlansResponse\"\x00\x12S\n\x06Import\x12\".milvus.proto.milvus.ImportRequest\x1a#.milvus.proto.milvus.ImportResponse\"\x00\x12k\n\x0eGetImportState\x12*.milvus.proto.milvus.GetImportStateRequest\x1a+.milvus.proto.milvus.GetImportStateResponse\"\x00\x12n\n\x0fListImportTasks\x12+.milvus.proto.milvus.ListImportTasksRequest\x1a,.milvus.proto.milvus.ListImportTasksResponse\"\x00\x12_\n\x10\x43reateCredential\x12,.milvus.proto.milvus.CreateCredentialRequest\x1a\x1b.milvus.proto.common.Status\"\x00\x12_\n\x10UpdateCredential\x12,.milvus.proto.milvus.UpdateCredentialRequest\x1a\x1b.milvus.proto.common.Status\"\x00\x12_\n\x10\x44\x65leteCredential\x12,.milvus.proto.milvus.DeleteCredentialRequest\x1a\x1b.milvus.proto.common.Status\"\x00\x12h\n\rListCredUsers\x12).milvus.proto.milvus.ListCredUsersRequest\x1a*.milvus.proto.milvus.ListCredUsersResponse\"\x00\x12S\n\nCreateRole\x12&.milvus.proto.milvus.CreateRoleRequest\x1a\x1b.milvus.proto.common.Status\"\x00\x12O\n\x08\x44ropRole\x12$.milvus.proto.milvus.DropRoleRequest\x1a\x1b.milvus.proto.common.Status\"\x00\x12]\n\x0fOperateUserRole\x12+.milvus.proto.milvus.OperateUserRoleRequest\x1a\x1b.milvus.proto.common.Status\"\x00\x12_\n\nSelectRole\x12&.milvus.proto.milvus.SelectRoleRequest\x1a\'.milvus.proto.milvus.SelectRoleResponse\"\x00\x12_\n\nSelectUser\x12&.milvus.proto.milvus.SelectUserRequest\x1a\'.milvus.proto.milvus.SelectUserResponse\"\x00\x12k\n\x0eSelectResource\x12*.milvus.proto.milvus.SelectResourceRequest\x1a+.milvus.proto.milvus.SelectResourceResponse\"\x00\x12_\n\x10OperatePrivilege\x12,.milvus.proto.milvus.OperatePrivilegeRequest\x1a\x1b.milvus.proto.common.Status\"\x00\x12\x62\n\x0bSelectGrant\x12\'.milvus.proto.milvus.SelectGrantRequest\x1a(.milvus.proto.milvus.SelectGrantResponse\"\x00\x32u\n\x0cProxyService\x12\x65\n\x0cRegisterLink\x12(.milvus.proto.milvus.RegisterLinkRequest\x1a).milvus.proto.milvus.RegisterLinkResponse\"\x00:U\n\x0emilvus_ext_obj\x12\x1c.google.protobuf.FileOptions\x18\xe9\x07 \x01(\x0b\x32\x1e.milvus.proto.milvus.MilvusExtBa\n\x0eio.milvus.grpcB\x0bMilvusProtoP\x01Z3github.com/milvus-io/milvus/internal/proto/milvuspb\xa0\x01\x01\xca>\x07\n\x05\x32.1.0b\x06proto3')

_SHOWTYPE = DESCRIPTOR.enum_types_by_name['ShowType']
ShowType = enum_type_wrapper.EnumTypeWrapper(_SHOWTYPE)
_OPERATEUSERROLETYPE = DESCRIPTOR.enum_types_by_name['OperateUserRoleType']
OperateUserRoleType = enum_type_wrapper.EnumTypeWrapper(_OPERATEUSERROLETYPE)
_OPERATEPRIVILEGETYPE = DESCRIPTOR.enum_types_by_name['OperatePrivilegeType']
OperatePrivilegeType = enum_type_wrapper.EnumTypeWrapper(_OPERATEPRIVILEGETYPE)
All = 0
InMemory = 1
AddUserToRole = 0
RemoveUserFromRole = 1
Grant = 0
Revoke = 1

MILVUS_EXT_OBJ_FIELD_NUMBER = 1001
milvus_ext_obj = DESCRIPTOR.extensions_by_name['milvus_ext_obj']

_CREATEALIASREQUEST = DESCRIPTOR.message_types_by_name['CreateAliasRequest']
_DROPALIASREQUEST = DESCRIPTOR.message_types_by_name['DropAliasRequest']
_ALTERALIASREQUEST = DESCRIPTOR.message_types_by_name['AlterAliasRequest']
_CREATECOLLECTIONREQUEST = DESCRIPTOR.message_types_by_name['CreateCollectionRequest']
_DROPCOLLECTIONREQUEST = DESCRIPTOR.message_types_by_name['DropCollectionRequest']
_HASCOLLECTIONREQUEST = DESCRIPTOR.message_types_by_name['HasCollectionRequest']
_BOOLRESPONSE = DESCRIPTOR.message_types_by_name['BoolResponse']
_STRINGRESPONSE = DESCRIPTOR.message_types_by_name['StringResponse']
_DESCRIBECOLLECTIONREQUEST = DESCRIPTOR.message_types_by_name['DescribeCollectionRequest']
_DESCRIBECOLLECTIONRESPONSE = DESCRIPTOR.message_types_by_name['DescribeCollectionResponse']
_LOADCOLLECTIONREQUEST = DESCRIPTOR.message_types_by_name['LoadCollectionRequest']
_RELEASECOLLECTIONREQUEST = DESCRIPTOR.message_types_by_name['ReleaseCollectionRequest']
_GETCOLLECTIONSTATISTICSREQUEST = DESCRIPTOR.message_types_by_name['GetCollectionStatisticsRequest']
_GETCOLLECTIONSTATISTICSRESPONSE = DESCRIPTOR.message_types_by_name['GetCollectionStatisticsResponse']
_SHOWCOLLECTIONSREQUEST = DESCRIPTOR.message_types_by_name['ShowCollectionsRequest']
_SHOWCOLLECTIONSRESPONSE = DESCRIPTOR.message_types_by_name['ShowCollectionsResponse']
_CREATEPARTITIONREQUEST = DESCRIPTOR.message_types_by_name['CreatePartitionRequest']
_DROPPARTITIONREQUEST = DESCRIPTOR.message_types_by_name['DropPartitionRequest']
_HASPARTITIONREQUEST = DESCRIPTOR.message_types_by_name['HasPartitionRequest']
_LOADPARTITIONSREQUEST = DESCRIPTOR.message_types_by_name['LoadPartitionsRequest']
_RELEASEPARTITIONSREQUEST = DESCRIPTOR.message_types_by_name['ReleasePartitionsRequest']
_GETPARTITIONSTATISTICSREQUEST = DESCRIPTOR.message_types_by_name['GetPartitionStatisticsRequest']
_GETPARTITIONSTATISTICSRESPONSE = DESCRIPTOR.message_types_by_name['GetPartitionStatisticsResponse']
_SHOWPARTITIONSREQUEST = DESCRIPTOR.message_types_by_name['ShowPartitionsRequest']
_SHOWPARTITIONSRESPONSE = DESCRIPTOR.message_types_by_name['ShowPartitionsResponse']
_DESCRIBESEGMENTREQUEST = DESCRIPTOR.message_types_by_name['DescribeSegmentRequest']
_DESCRIBESEGMENTRESPONSE = DESCRIPTOR.message_types_by_name['DescribeSegmentResponse']
_SHOWSEGMENTSREQUEST = DESCRIPTOR.message_types_by_name['ShowSegmentsRequest']
_SHOWSEGMENTSRESPONSE = DESCRIPTOR.message_types_by_name['ShowSegmentsResponse']
_CREATEINDEXREQUEST = DESCRIPTOR.message_types_by_name['CreateIndexRequest']
_DESCRIBEINDEXREQUEST = DESCRIPTOR.message_types_by_name['DescribeIndexRequest']
_INDEXDESCRIPTION = DESCRIPTOR.message_types_by_name['IndexDescription']
_DESCRIBEINDEXRESPONSE = DESCRIPTOR.message_types_by_name['DescribeIndexResponse']
_GETINDEXBUILDPROGRESSREQUEST = DESCRIPTOR.message_types_by_name['GetIndexBuildProgressRequest']
_GETINDEXBUILDPROGRESSRESPONSE = DESCRIPTOR.message_types_by_name['GetIndexBuildProgressResponse']
_GETINDEXSTATEREQUEST = DESCRIPTOR.message_types_by_name['GetIndexStateRequest']
_GETINDEXSTATERESPONSE = DESCRIPTOR.message_types_by_name['GetIndexStateResponse']
_DROPINDEXREQUEST = DESCRIPTOR.message_types_by_name['DropIndexRequest']
_INSERTREQUEST = DESCRIPTOR.message_types_by_name['InsertRequest']
_MUTATIONRESULT = DESCRIPTOR.message_types_by_name['MutationResult']
_DELETEREQUEST = DESCRIPTOR.message_types_by_name['DeleteRequest']
_SEARCHREQUEST = DESCRIPTOR.message_types_by_name['SearchRequest']
_HITS = DESCRIPTOR.message_types_by_name['Hits']
_SEARCHRESULTS = DESCRIPTOR.message_types_by_name['SearchResults']
_FLUSHREQUEST = DESCRIPTOR.message_types_by_name['FlushRequest']
_FLUSHRESPONSE = DESCRIPTOR.message_types_by_name['FlushResponse']
_FLUSHRESPONSE_COLLSEGIDSENTRY = _FLUSHRESPONSE.nested_types_by_name['CollSegIDsEntry']
_QUERYREQUEST = DESCRIPTOR.message_types_by_name['QueryRequest']
_QUERYRESULTS = DESCRIPTOR.message_types_by_name['QueryResults']
_VECTORIDS = DESCRIPTOR.message_types_by_name['VectorIDs']
_VECTORSARRAY = DESCRIPTOR.message_types_by_name['VectorsArray']
_CALCDISTANCEREQUEST = DESCRIPTOR.message_types_by_name['CalcDistanceRequest']
_CALCDISTANCERESULTS = DESCRIPTOR.message_types_by_name['CalcDistanceResults']
_PERSISTENTSEGMENTINFO = DESCRIPTOR.message_types_by_name['PersistentSegmentInfo']
_GETPERSISTENTSEGMENTINFOREQUEST = DESCRIPTOR.message_types_by_name['GetPersistentSegmentInfoRequest']
_GETPERSISTENTSEGMENTINFORESPONSE = DESCRIPTOR.message_types_by_name['GetPersistentSegmentInfoResponse']
_QUERYSEGMENTINFO = DESCRIPTOR.message_types_by_name['QuerySegmentInfo']
_GETQUERYSEGMENTINFOREQUEST = DESCRIPTOR.message_types_by_name['GetQuerySegmentInfoRequest']
_GETQUERYSEGMENTINFORESPONSE = DESCRIPTOR.message_types_by_name['GetQuerySegmentInfoResponse']
_DUMMYREQUEST = DESCRIPTOR.message_types_by_name['DummyRequest']
_DUMMYRESPONSE = DESCRIPTOR.message_types_by_name['DummyResponse']
_REGISTERLINKREQUEST = DESCRIPTOR.message_types_by_name['RegisterLinkRequest']
_REGISTERLINKRESPONSE = DESCRIPTOR.message_types_by_name['RegisterLinkResponse']
_GETMETRICSREQUEST = DESCRIPTOR.message_types_by_name['GetMetricsRequest']
_GETMETRICSRESPONSE = DESCRIPTOR.message_types_by_name['GetMetricsResponse']
_LOADBALANCEREQUEST = DESCRIPTOR.message_types_by_name['LoadBalanceRequest']
_MANUALCOMPACTIONREQUEST = DESCRIPTOR.message_types_by_name['ManualCompactionRequest']
_MANUALCOMPACTIONRESPONSE = DESCRIPTOR.message_types_by_name['ManualCompactionResponse']
_GETCOMPACTIONSTATEREQUEST = DESCRIPTOR.message_types_by_name['GetCompactionStateRequest']
_GETCOMPACTIONSTATERESPONSE = DESCRIPTOR.message_types_by_name['GetCompactionStateResponse']
_GETCOMPACTIONPLANSREQUEST = DESCRIPTOR.message_types_by_name['GetCompactionPlansRequest']
_GETCOMPACTIONPLANSRESPONSE = DESCRIPTOR.message_types_by_name['GetCompactionPlansResponse']
_COMPACTIONMERGEINFO = DESCRIPTOR.message_types_by_name['CompactionMergeInfo']
_GETFLUSHSTATEREQUEST = DESCRIPTOR.message_types_by_name['GetFlushStateRequest']
_GETFLUSHSTATERESPONSE = DESCRIPTOR.message_types_by_name['GetFlushStateResponse']
_IMPORTREQUEST = DESCRIPTOR.message_types_by_name['ImportRequest']
_IMPORTRESPONSE = DESCRIPTOR.message_types_by_name['ImportResponse']
_GETIMPORTSTATEREQUEST = DESCRIPTOR.message_types_by_name['GetImportStateRequest']
_GETIMPORTSTATERESPONSE = DESCRIPTOR.message_types_by_name['GetImportStateResponse']
_LISTIMPORTTASKSREQUEST = DESCRIPTOR.message_types_by_name['ListImportTasksRequest']
_LISTIMPORTTASKSRESPONSE = DESCRIPTOR.message_types_by_name['ListImportTasksResponse']
_GETREPLICASREQUEST = DESCRIPTOR.message_types_by_name['GetReplicasRequest']
_GETREPLICASRESPONSE = DESCRIPTOR.message_types_by_name['GetReplicasResponse']
_REPLICAINFO = DESCRIPTOR.message_types_by_name['ReplicaInfo']
_SHARDREPLICA = DESCRIPTOR.message_types_by_name['ShardReplica']
_CREATECREDENTIALREQUEST = DESCRIPTOR.message_types_by_name['CreateCredentialRequest']
_UPDATECREDENTIALREQUEST = DESCRIPTOR.message_types_by_name['UpdateCredentialRequest']
_DELETECREDENTIALREQUEST = DESCRIPTOR.message_types_by_name['DeleteCredentialRequest']
_LISTCREDUSERSRESPONSE = DESCRIPTOR.message_types_by_name['ListCredUsersResponse']
_LISTCREDUSERSREQUEST = DESCRIPTOR.message_types_by_name['ListCredUsersRequest']
_ROLEENTITY = DESCRIPTOR.message_types_by_name['RoleEntity']
_USERENTITY = DESCRIPTOR.message_types_by_name['UserEntity']
_CREATEROLEREQUEST = DESCRIPTOR.message_types_by_name['CreateRoleRequest']
_DROPROLEREQUEST = DESCRIPTOR.message_types_by_name['DropRoleRequest']
_OPERATEUSERROLEREQUEST = DESCRIPTOR.message_types_by_name['OperateUserRoleRequest']
_SELECTROLEREQUEST = DESCRIPTOR.message_types_by_name['SelectRoleRequest']
_ROLERESULT = DESCRIPTOR.message_types_by_name['RoleResult']
_SELECTROLERESPONSE = DESCRIPTOR.message_types_by_name['SelectRoleResponse']
_SELECTUSERREQUEST = DESCRIPTOR.message_types_by_name['SelectUserRequest']
_USERRESULT = DESCRIPTOR.message_types_by_name['UserResult']
_SELECTUSERRESPONSE = DESCRIPTOR.message_types_by_name['SelectUserResponse']
_RESOURCEENTITY = DESCRIPTOR.message_types_by_name['ResourceEntity']
_PRIVILEGEENTITY = DESCRIPTOR.message_types_by_name['PrivilegeEntity']
_SELECTRESOURCEREQUEST = DESCRIPTOR.message_types_by_name['SelectResourceRequest']
_RESOURCERESULT = DESCRIPTOR.message_types_by_name['ResourceResult']
_SELECTRESOURCERESPONSE = DESCRIPTOR.message_types_by_name['SelectResourceResponse']
_PRINCIPALENTITY = DESCRIPTOR.message_types_by_name['PrincipalEntity']
_GRANTORENTITY = DESCRIPTOR.message_types_by_name['GrantorEntity']
_GRANTENTITY = DESCRIPTOR.message_types_by_name['GrantEntity']
_SELECTGRANTREQUEST = DESCRIPTOR.message_types_by_name['SelectGrantRequest']
_SELECTGRANTRESPONSE = DESCRIPTOR.message_types_by_name['SelectGrantResponse']
_OPERATEPRIVILEGEREQUEST = DESCRIPTOR.message_types_by_name['OperatePrivilegeRequest']
_MILVUSEXT = DESCRIPTOR.message_types_by_name['MilvusExt']
CreateAliasRequest = _reflection.GeneratedProtocolMessageType('CreateAliasRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEALIASREQUEST,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.CreateAliasRequest)
  })
_sym_db.RegisterMessage(CreateAliasRequest)

DropAliasRequest = _reflection.GeneratedProtocolMessageType('DropAliasRequest', (_message.Message,), {
  'DESCRIPTOR' : _DROPALIASREQUEST,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.DropAliasRequest)
  })
_sym_db.RegisterMessage(DropAliasRequest)

AlterAliasRequest = _reflection.GeneratedProtocolMessageType('AlterAliasRequest', (_message.Message,), {
  'DESCRIPTOR' : _ALTERALIASREQUEST,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.AlterAliasRequest)
  })
_sym_db.RegisterMessage(AlterAliasRequest)

CreateCollectionRequest = _reflection.GeneratedProtocolMessageType('CreateCollectionRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATECOLLECTIONREQUEST,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.CreateCollectionRequest)
  })
_sym_db.RegisterMessage(CreateCollectionRequest)

DropCollectionRequest = _reflection.GeneratedProtocolMessageType('DropCollectionRequest', (_message.Message,), {
  'DESCRIPTOR' : _DROPCOLLECTIONREQUEST,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.DropCollectionRequest)
  })
_sym_db.RegisterMessage(DropCollectionRequest)

HasCollectionRequest = _reflection.GeneratedProtocolMessageType('HasCollectionRequest', (_message.Message,), {
  'DESCRIPTOR' : _HASCOLLECTIONREQUEST,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.HasCollectionRequest)
  })
_sym_db.RegisterMessage(HasCollectionRequest)

BoolResponse = _reflection.GeneratedProtocolMessageType('BoolResponse', (_message.Message,), {
  'DESCRIPTOR' : _BOOLRESPONSE,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.BoolResponse)
  })
_sym_db.RegisterMessage(BoolResponse)

StringResponse = _reflection.GeneratedProtocolMessageType('StringResponse', (_message.Message,), {
  'DESCRIPTOR' : _STRINGRESPONSE,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.StringResponse)
  })
_sym_db.RegisterMessage(StringResponse)

DescribeCollectionRequest = _reflection.GeneratedProtocolMessageType('DescribeCollectionRequest', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBECOLLECTIONREQUEST,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.DescribeCollectionRequest)
  })
_sym_db.RegisterMessage(DescribeCollectionRequest)

DescribeCollectionResponse = _reflection.GeneratedProtocolMessageType('DescribeCollectionResponse', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBECOLLECTIONRESPONSE,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.DescribeCollectionResponse)
  })
_sym_db.RegisterMessage(DescribeCollectionResponse)

LoadCollectionRequest = _reflection.GeneratedProtocolMessageType('LoadCollectionRequest', (_message.Message,), {
  'DESCRIPTOR' : _LOADCOLLECTIONREQUEST,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.LoadCollectionRequest)
  })
_sym_db.RegisterMessage(LoadCollectionRequest)

ReleaseCollectionRequest = _reflection.GeneratedProtocolMessageType('ReleaseCollectionRequest', (_message.Message,), {
  'DESCRIPTOR' : _RELEASECOLLECTIONREQUEST,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.ReleaseCollectionRequest)
  })
_sym_db.RegisterMessage(ReleaseCollectionRequest)

GetCollectionStatisticsRequest = _reflection.GeneratedProtocolMessageType('GetCollectionStatisticsRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETCOLLECTIONSTATISTICSREQUEST,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.GetCollectionStatisticsRequest)
  })
_sym_db.RegisterMessage(GetCollectionStatisticsRequest)

GetCollectionStatisticsResponse = _reflection.GeneratedProtocolMessageType('GetCollectionStatisticsResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETCOLLECTIONSTATISTICSRESPONSE,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.GetCollectionStatisticsResponse)
  })
_sym_db.RegisterMessage(GetCollectionStatisticsResponse)

ShowCollectionsRequest = _reflection.GeneratedProtocolMessageType('ShowCollectionsRequest', (_message.Message,), {
  'DESCRIPTOR' : _SHOWCOLLECTIONSREQUEST,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.ShowCollectionsRequest)
  })
_sym_db.RegisterMessage(ShowCollectionsRequest)

ShowCollectionsResponse = _reflection.GeneratedProtocolMessageType('ShowCollectionsResponse', (_message.Message,), {
  'DESCRIPTOR' : _SHOWCOLLECTIONSRESPONSE,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.ShowCollectionsResponse)
  })
_sym_db.RegisterMessage(ShowCollectionsResponse)

CreatePartitionRequest = _reflection.GeneratedProtocolMessageType('CreatePartitionRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEPARTITIONREQUEST,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.CreatePartitionRequest)
  })
_sym_db.RegisterMessage(CreatePartitionRequest)

DropPartitionRequest = _reflection.GeneratedProtocolMessageType('DropPartitionRequest', (_message.Message,), {
  'DESCRIPTOR' : _DROPPARTITIONREQUEST,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.DropPartitionRequest)
  })
_sym_db.RegisterMessage(DropPartitionRequest)

HasPartitionRequest = _reflection.GeneratedProtocolMessageType('HasPartitionRequest', (_message.Message,), {
  'DESCRIPTOR' : _HASPARTITIONREQUEST,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.HasPartitionRequest)
  })
_sym_db.RegisterMessage(HasPartitionRequest)

LoadPartitionsRequest = _reflection.GeneratedProtocolMessageType('LoadPartitionsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LOADPARTITIONSREQUEST,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.LoadPartitionsRequest)
  })
_sym_db.RegisterMessage(LoadPartitionsRequest)

ReleasePartitionsRequest = _reflection.GeneratedProtocolMessageType('ReleasePartitionsRequest', (_message.Message,), {
  'DESCRIPTOR' : _RELEASEPARTITIONSREQUEST,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.ReleasePartitionsRequest)
  })
_sym_db.RegisterMessage(ReleasePartitionsRequest)

GetPartitionStatisticsRequest = _reflection.GeneratedProtocolMessageType('GetPartitionStatisticsRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETPARTITIONSTATISTICSREQUEST,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.GetPartitionStatisticsRequest)
  })
_sym_db.RegisterMessage(GetPartitionStatisticsRequest)

GetPartitionStatisticsResponse = _reflection.GeneratedProtocolMessageType('GetPartitionStatisticsResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETPARTITIONSTATISTICSRESPONSE,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.GetPartitionStatisticsResponse)
  })
_sym_db.RegisterMessage(GetPartitionStatisticsResponse)

ShowPartitionsRequest = _reflection.GeneratedProtocolMessageType('ShowPartitionsRequest', (_message.Message,), {
  'DESCRIPTOR' : _SHOWPARTITIONSREQUEST,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.ShowPartitionsRequest)
  })
_sym_db.RegisterMessage(ShowPartitionsRequest)

ShowPartitionsResponse = _reflection.GeneratedProtocolMessageType('ShowPartitionsResponse', (_message.Message,), {
  'DESCRIPTOR' : _SHOWPARTITIONSRESPONSE,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.ShowPartitionsResponse)
  })
_sym_db.RegisterMessage(ShowPartitionsResponse)

DescribeSegmentRequest = _reflection.GeneratedProtocolMessageType('DescribeSegmentRequest', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBESEGMENTREQUEST,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.DescribeSegmentRequest)
  })
_sym_db.RegisterMessage(DescribeSegmentRequest)

DescribeSegmentResponse = _reflection.GeneratedProtocolMessageType('DescribeSegmentResponse', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBESEGMENTRESPONSE,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.DescribeSegmentResponse)
  })
_sym_db.RegisterMessage(DescribeSegmentResponse)

ShowSegmentsRequest = _reflection.GeneratedProtocolMessageType('ShowSegmentsRequest', (_message.Message,), {
  'DESCRIPTOR' : _SHOWSEGMENTSREQUEST,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.ShowSegmentsRequest)
  })
_sym_db.RegisterMessage(ShowSegmentsRequest)

ShowSegmentsResponse = _reflection.GeneratedProtocolMessageType('ShowSegmentsResponse', (_message.Message,), {
  'DESCRIPTOR' : _SHOWSEGMENTSRESPONSE,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.ShowSegmentsResponse)
  })
_sym_db.RegisterMessage(ShowSegmentsResponse)

CreateIndexRequest = _reflection.GeneratedProtocolMessageType('CreateIndexRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEINDEXREQUEST,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.CreateIndexRequest)
  })
_sym_db.RegisterMessage(CreateIndexRequest)

DescribeIndexRequest = _reflection.GeneratedProtocolMessageType('DescribeIndexRequest', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBEINDEXREQUEST,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.DescribeIndexRequest)
  })
_sym_db.RegisterMessage(DescribeIndexRequest)

IndexDescription = _reflection.GeneratedProtocolMessageType('IndexDescription', (_message.Message,), {
  'DESCRIPTOR' : _INDEXDESCRIPTION,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.IndexDescription)
  })
_sym_db.RegisterMessage(IndexDescription)

DescribeIndexResponse = _reflection.GeneratedProtocolMessageType('DescribeIndexResponse', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBEINDEXRESPONSE,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.DescribeIndexResponse)
  })
_sym_db.RegisterMessage(DescribeIndexResponse)

GetIndexBuildProgressRequest = _reflection.GeneratedProtocolMessageType('GetIndexBuildProgressRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETINDEXBUILDPROGRESSREQUEST,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.GetIndexBuildProgressRequest)
  })
_sym_db.RegisterMessage(GetIndexBuildProgressRequest)

GetIndexBuildProgressResponse = _reflection.GeneratedProtocolMessageType('GetIndexBuildProgressResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETINDEXBUILDPROGRESSRESPONSE,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.GetIndexBuildProgressResponse)
  })
_sym_db.RegisterMessage(GetIndexBuildProgressResponse)

GetIndexStateRequest = _reflection.GeneratedProtocolMessageType('GetIndexStateRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETINDEXSTATEREQUEST,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.GetIndexStateRequest)
  })
_sym_db.RegisterMessage(GetIndexStateRequest)

GetIndexStateResponse = _reflection.GeneratedProtocolMessageType('GetIndexStateResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETINDEXSTATERESPONSE,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.GetIndexStateResponse)
  })
_sym_db.RegisterMessage(GetIndexStateResponse)

DropIndexRequest = _reflection.GeneratedProtocolMessageType('DropIndexRequest', (_message.Message,), {
  'DESCRIPTOR' : _DROPINDEXREQUEST,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.DropIndexRequest)
  })
_sym_db.RegisterMessage(DropIndexRequest)

InsertRequest = _reflection.GeneratedProtocolMessageType('InsertRequest', (_message.Message,), {
  'DESCRIPTOR' : _INSERTREQUEST,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.InsertRequest)
  })
_sym_db.RegisterMessage(InsertRequest)

MutationResult = _reflection.GeneratedProtocolMessageType('MutationResult', (_message.Message,), {
  'DESCRIPTOR' : _MUTATIONRESULT,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.MutationResult)
  })
_sym_db.RegisterMessage(MutationResult)

DeleteRequest = _reflection.GeneratedProtocolMessageType('DeleteRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEREQUEST,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.DeleteRequest)
  })
_sym_db.RegisterMessage(DeleteRequest)

SearchRequest = _reflection.GeneratedProtocolMessageType('SearchRequest', (_message.Message,), {
  'DESCRIPTOR' : _SEARCHREQUEST,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.SearchRequest)
  })
_sym_db.RegisterMessage(SearchRequest)

Hits = _reflection.GeneratedProtocolMessageType('Hits', (_message.Message,), {
  'DESCRIPTOR' : _HITS,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.Hits)
  })
_sym_db.RegisterMessage(Hits)

SearchResults = _reflection.GeneratedProtocolMessageType('SearchResults', (_message.Message,), {
  'DESCRIPTOR' : _SEARCHRESULTS,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.SearchResults)
  })
_sym_db.RegisterMessage(SearchResults)

FlushRequest = _reflection.GeneratedProtocolMessageType('FlushRequest', (_message.Message,), {
  'DESCRIPTOR' : _FLUSHREQUEST,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.FlushRequest)
  })
_sym_db.RegisterMessage(FlushRequest)

FlushResponse = _reflection.GeneratedProtocolMessageType('FlushResponse', (_message.Message,), {

  'CollSegIDsEntry' : _reflection.GeneratedProtocolMessageType('CollSegIDsEntry', (_message.Message,), {
    'DESCRIPTOR' : _FLUSHRESPONSE_COLLSEGIDSENTRY,
    '__module__' : 'milvus_pb2'
    # @@protoc_insertion_point(class_scope:milvus.proto.milvus.FlushResponse.CollSegIDsEntry)
    })
  ,
  'DESCRIPTOR' : _FLUSHRESPONSE,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.FlushResponse)
  })
_sym_db.RegisterMessage(FlushResponse)
_sym_db.RegisterMessage(FlushResponse.CollSegIDsEntry)

QueryRequest = _reflection.GeneratedProtocolMessageType('QueryRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYREQUEST,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.QueryRequest)
  })
_sym_db.RegisterMessage(QueryRequest)

QueryResults = _reflection.GeneratedProtocolMessageType('QueryResults', (_message.Message,), {
  'DESCRIPTOR' : _QUERYRESULTS,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.QueryResults)
  })
_sym_db.RegisterMessage(QueryResults)

VectorIDs = _reflection.GeneratedProtocolMessageType('VectorIDs', (_message.Message,), {
  'DESCRIPTOR' : _VECTORIDS,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.VectorIDs)
  })
_sym_db.RegisterMessage(VectorIDs)

VectorsArray = _reflection.GeneratedProtocolMessageType('VectorsArray', (_message.Message,), {
  'DESCRIPTOR' : _VECTORSARRAY,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.VectorsArray)
  })
_sym_db.RegisterMessage(VectorsArray)

CalcDistanceRequest = _reflection.GeneratedProtocolMessageType('CalcDistanceRequest', (_message.Message,), {
  'DESCRIPTOR' : _CALCDISTANCEREQUEST,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.CalcDistanceRequest)
  })
_sym_db.RegisterMessage(CalcDistanceRequest)

CalcDistanceResults = _reflection.GeneratedProtocolMessageType('CalcDistanceResults', (_message.Message,), {
  'DESCRIPTOR' : _CALCDISTANCERESULTS,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.CalcDistanceResults)
  })
_sym_db.RegisterMessage(CalcDistanceResults)

PersistentSegmentInfo = _reflection.GeneratedProtocolMessageType('PersistentSegmentInfo', (_message.Message,), {
  'DESCRIPTOR' : _PERSISTENTSEGMENTINFO,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.PersistentSegmentInfo)
  })
_sym_db.RegisterMessage(PersistentSegmentInfo)

GetPersistentSegmentInfoRequest = _reflection.GeneratedProtocolMessageType('GetPersistentSegmentInfoRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETPERSISTENTSEGMENTINFOREQUEST,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.GetPersistentSegmentInfoRequest)
  })
_sym_db.RegisterMessage(GetPersistentSegmentInfoRequest)

GetPersistentSegmentInfoResponse = _reflection.GeneratedProtocolMessageType('GetPersistentSegmentInfoResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETPERSISTENTSEGMENTINFORESPONSE,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.GetPersistentSegmentInfoResponse)
  })
_sym_db.RegisterMessage(GetPersistentSegmentInfoResponse)

QuerySegmentInfo = _reflection.GeneratedProtocolMessageType('QuerySegmentInfo', (_message.Message,), {
  'DESCRIPTOR' : _QUERYSEGMENTINFO,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.QuerySegmentInfo)
  })
_sym_db.RegisterMessage(QuerySegmentInfo)

GetQuerySegmentInfoRequest = _reflection.GeneratedProtocolMessageType('GetQuerySegmentInfoRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETQUERYSEGMENTINFOREQUEST,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.GetQuerySegmentInfoRequest)
  })
_sym_db.RegisterMessage(GetQuerySegmentInfoRequest)

GetQuerySegmentInfoResponse = _reflection.GeneratedProtocolMessageType('GetQuerySegmentInfoResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETQUERYSEGMENTINFORESPONSE,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.GetQuerySegmentInfoResponse)
  })
_sym_db.RegisterMessage(GetQuerySegmentInfoResponse)

DummyRequest = _reflection.GeneratedProtocolMessageType('DummyRequest', (_message.Message,), {
  'DESCRIPTOR' : _DUMMYREQUEST,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.DummyRequest)
  })
_sym_db.RegisterMessage(DummyRequest)

DummyResponse = _reflection.GeneratedProtocolMessageType('DummyResponse', (_message.Message,), {
  'DESCRIPTOR' : _DUMMYRESPONSE,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.DummyResponse)
  })
_sym_db.RegisterMessage(DummyResponse)

RegisterLinkRequest = _reflection.GeneratedProtocolMessageType('RegisterLinkRequest', (_message.Message,), {
  'DESCRIPTOR' : _REGISTERLINKREQUEST,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.RegisterLinkRequest)
  })
_sym_db.RegisterMessage(RegisterLinkRequest)

RegisterLinkResponse = _reflection.GeneratedProtocolMessageType('RegisterLinkResponse', (_message.Message,), {
  'DESCRIPTOR' : _REGISTERLINKRESPONSE,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.RegisterLinkResponse)
  })
_sym_db.RegisterMessage(RegisterLinkResponse)

GetMetricsRequest = _reflection.GeneratedProtocolMessageType('GetMetricsRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETMETRICSREQUEST,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.GetMetricsRequest)
  })
_sym_db.RegisterMessage(GetMetricsRequest)

GetMetricsResponse = _reflection.GeneratedProtocolMessageType('GetMetricsResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETMETRICSRESPONSE,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.GetMetricsResponse)
  })
_sym_db.RegisterMessage(GetMetricsResponse)

LoadBalanceRequest = _reflection.GeneratedProtocolMessageType('LoadBalanceRequest', (_message.Message,), {
  'DESCRIPTOR' : _LOADBALANCEREQUEST,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.LoadBalanceRequest)
  })
_sym_db.RegisterMessage(LoadBalanceRequest)

ManualCompactionRequest = _reflection.GeneratedProtocolMessageType('ManualCompactionRequest', (_message.Message,), {
  'DESCRIPTOR' : _MANUALCOMPACTIONREQUEST,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.ManualCompactionRequest)
  })
_sym_db.RegisterMessage(ManualCompactionRequest)

ManualCompactionResponse = _reflection.GeneratedProtocolMessageType('ManualCompactionResponse', (_message.Message,), {
  'DESCRIPTOR' : _MANUALCOMPACTIONRESPONSE,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.ManualCompactionResponse)
  })
_sym_db.RegisterMessage(ManualCompactionResponse)

GetCompactionStateRequest = _reflection.GeneratedProtocolMessageType('GetCompactionStateRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETCOMPACTIONSTATEREQUEST,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.GetCompactionStateRequest)
  })
_sym_db.RegisterMessage(GetCompactionStateRequest)

GetCompactionStateResponse = _reflection.GeneratedProtocolMessageType('GetCompactionStateResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETCOMPACTIONSTATERESPONSE,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.GetCompactionStateResponse)
  })
_sym_db.RegisterMessage(GetCompactionStateResponse)

GetCompactionPlansRequest = _reflection.GeneratedProtocolMessageType('GetCompactionPlansRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETCOMPACTIONPLANSREQUEST,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.GetCompactionPlansRequest)
  })
_sym_db.RegisterMessage(GetCompactionPlansRequest)

GetCompactionPlansResponse = _reflection.GeneratedProtocolMessageType('GetCompactionPlansResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETCOMPACTIONPLANSRESPONSE,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.GetCompactionPlansResponse)
  })
_sym_db.RegisterMessage(GetCompactionPlansResponse)

CompactionMergeInfo = _reflection.GeneratedProtocolMessageType('CompactionMergeInfo', (_message.Message,), {
  'DESCRIPTOR' : _COMPACTIONMERGEINFO,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.CompactionMergeInfo)
  })
_sym_db.RegisterMessage(CompactionMergeInfo)

GetFlushStateRequest = _reflection.GeneratedProtocolMessageType('GetFlushStateRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETFLUSHSTATEREQUEST,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.GetFlushStateRequest)
  })
_sym_db.RegisterMessage(GetFlushStateRequest)

GetFlushStateResponse = _reflection.GeneratedProtocolMessageType('GetFlushStateResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETFLUSHSTATERESPONSE,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.GetFlushStateResponse)
  })
_sym_db.RegisterMessage(GetFlushStateResponse)

ImportRequest = _reflection.GeneratedProtocolMessageType('ImportRequest', (_message.Message,), {
  'DESCRIPTOR' : _IMPORTREQUEST,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.ImportRequest)
  })
_sym_db.RegisterMessage(ImportRequest)

ImportResponse = _reflection.GeneratedProtocolMessageType('ImportResponse', (_message.Message,), {
  'DESCRIPTOR' : _IMPORTRESPONSE,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.ImportResponse)
  })
_sym_db.RegisterMessage(ImportResponse)

GetImportStateRequest = _reflection.GeneratedProtocolMessageType('GetImportStateRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETIMPORTSTATEREQUEST,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.GetImportStateRequest)
  })
_sym_db.RegisterMessage(GetImportStateRequest)

GetImportStateResponse = _reflection.GeneratedProtocolMessageType('GetImportStateResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETIMPORTSTATERESPONSE,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.GetImportStateResponse)
  })
_sym_db.RegisterMessage(GetImportStateResponse)

ListImportTasksRequest = _reflection.GeneratedProtocolMessageType('ListImportTasksRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTIMPORTTASKSREQUEST,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.ListImportTasksRequest)
  })
_sym_db.RegisterMessage(ListImportTasksRequest)

ListImportTasksResponse = _reflection.GeneratedProtocolMessageType('ListImportTasksResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTIMPORTTASKSRESPONSE,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.ListImportTasksResponse)
  })
_sym_db.RegisterMessage(ListImportTasksResponse)

GetReplicasRequest = _reflection.GeneratedProtocolMessageType('GetReplicasRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETREPLICASREQUEST,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.GetReplicasRequest)
  })
_sym_db.RegisterMessage(GetReplicasRequest)

GetReplicasResponse = _reflection.GeneratedProtocolMessageType('GetReplicasResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETREPLICASRESPONSE,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.GetReplicasResponse)
  })
_sym_db.RegisterMessage(GetReplicasResponse)

ReplicaInfo = _reflection.GeneratedProtocolMessageType('ReplicaInfo', (_message.Message,), {
  'DESCRIPTOR' : _REPLICAINFO,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.ReplicaInfo)
  })
_sym_db.RegisterMessage(ReplicaInfo)

ShardReplica = _reflection.GeneratedProtocolMessageType('ShardReplica', (_message.Message,), {
  'DESCRIPTOR' : _SHARDREPLICA,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.ShardReplica)
  })
_sym_db.RegisterMessage(ShardReplica)

CreateCredentialRequest = _reflection.GeneratedProtocolMessageType('CreateCredentialRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATECREDENTIALREQUEST,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.CreateCredentialRequest)
  })
_sym_db.RegisterMessage(CreateCredentialRequest)

UpdateCredentialRequest = _reflection.GeneratedProtocolMessageType('UpdateCredentialRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATECREDENTIALREQUEST,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.UpdateCredentialRequest)
  })
_sym_db.RegisterMessage(UpdateCredentialRequest)

DeleteCredentialRequest = _reflection.GeneratedProtocolMessageType('DeleteCredentialRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETECREDENTIALREQUEST,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.DeleteCredentialRequest)
  })
_sym_db.RegisterMessage(DeleteCredentialRequest)

ListCredUsersResponse = _reflection.GeneratedProtocolMessageType('ListCredUsersResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTCREDUSERSRESPONSE,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.ListCredUsersResponse)
  })
_sym_db.RegisterMessage(ListCredUsersResponse)

ListCredUsersRequest = _reflection.GeneratedProtocolMessageType('ListCredUsersRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTCREDUSERSREQUEST,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.ListCredUsersRequest)
  })
_sym_db.RegisterMessage(ListCredUsersRequest)

RoleEntity = _reflection.GeneratedProtocolMessageType('RoleEntity', (_message.Message,), {
  'DESCRIPTOR' : _ROLEENTITY,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.RoleEntity)
  })
_sym_db.RegisterMessage(RoleEntity)

UserEntity = _reflection.GeneratedProtocolMessageType('UserEntity', (_message.Message,), {
  'DESCRIPTOR' : _USERENTITY,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.UserEntity)
  })
_sym_db.RegisterMessage(UserEntity)

CreateRoleRequest = _reflection.GeneratedProtocolMessageType('CreateRoleRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEROLEREQUEST,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.CreateRoleRequest)
  })
_sym_db.RegisterMessage(CreateRoleRequest)

DropRoleRequest = _reflection.GeneratedProtocolMessageType('DropRoleRequest', (_message.Message,), {
  'DESCRIPTOR' : _DROPROLEREQUEST,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.DropRoleRequest)
  })
_sym_db.RegisterMessage(DropRoleRequest)

OperateUserRoleRequest = _reflection.GeneratedProtocolMessageType('OperateUserRoleRequest', (_message.Message,), {
  'DESCRIPTOR' : _OPERATEUSERROLEREQUEST,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.OperateUserRoleRequest)
  })
_sym_db.RegisterMessage(OperateUserRoleRequest)

SelectRoleRequest = _reflection.GeneratedProtocolMessageType('SelectRoleRequest', (_message.Message,), {
  'DESCRIPTOR' : _SELECTROLEREQUEST,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.SelectRoleRequest)
  })
_sym_db.RegisterMessage(SelectRoleRequest)

RoleResult = _reflection.GeneratedProtocolMessageType('RoleResult', (_message.Message,), {
  'DESCRIPTOR' : _ROLERESULT,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.RoleResult)
  })
_sym_db.RegisterMessage(RoleResult)

SelectRoleResponse = _reflection.GeneratedProtocolMessageType('SelectRoleResponse', (_message.Message,), {
  'DESCRIPTOR' : _SELECTROLERESPONSE,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.SelectRoleResponse)
  })
_sym_db.RegisterMessage(SelectRoleResponse)

SelectUserRequest = _reflection.GeneratedProtocolMessageType('SelectUserRequest', (_message.Message,), {
  'DESCRIPTOR' : _SELECTUSERREQUEST,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.SelectUserRequest)
  })
_sym_db.RegisterMessage(SelectUserRequest)

UserResult = _reflection.GeneratedProtocolMessageType('UserResult', (_message.Message,), {
  'DESCRIPTOR' : _USERRESULT,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.UserResult)
  })
_sym_db.RegisterMessage(UserResult)

SelectUserResponse = _reflection.GeneratedProtocolMessageType('SelectUserResponse', (_message.Message,), {
  'DESCRIPTOR' : _SELECTUSERRESPONSE,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.SelectUserResponse)
  })
_sym_db.RegisterMessage(SelectUserResponse)

ResourceEntity = _reflection.GeneratedProtocolMessageType('ResourceEntity', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCEENTITY,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.ResourceEntity)
  })
_sym_db.RegisterMessage(ResourceEntity)

PrivilegeEntity = _reflection.GeneratedProtocolMessageType('PrivilegeEntity', (_message.Message,), {
  'DESCRIPTOR' : _PRIVILEGEENTITY,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.PrivilegeEntity)
  })
_sym_db.RegisterMessage(PrivilegeEntity)

SelectResourceRequest = _reflection.GeneratedProtocolMessageType('SelectResourceRequest', (_message.Message,), {
  'DESCRIPTOR' : _SELECTRESOURCEREQUEST,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.SelectResourceRequest)
  })
_sym_db.RegisterMessage(SelectResourceRequest)

ResourceResult = _reflection.GeneratedProtocolMessageType('ResourceResult', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCERESULT,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.ResourceResult)
  })
_sym_db.RegisterMessage(ResourceResult)

SelectResourceResponse = _reflection.GeneratedProtocolMessageType('SelectResourceResponse', (_message.Message,), {
  'DESCRIPTOR' : _SELECTRESOURCERESPONSE,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.SelectResourceResponse)
  })
_sym_db.RegisterMessage(SelectResourceResponse)

PrincipalEntity = _reflection.GeneratedProtocolMessageType('PrincipalEntity', (_message.Message,), {
  'DESCRIPTOR' : _PRINCIPALENTITY,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.PrincipalEntity)
  })
_sym_db.RegisterMessage(PrincipalEntity)

GrantorEntity = _reflection.GeneratedProtocolMessageType('GrantorEntity', (_message.Message,), {
  'DESCRIPTOR' : _GRANTORENTITY,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.GrantorEntity)
  })
_sym_db.RegisterMessage(GrantorEntity)

GrantEntity = _reflection.GeneratedProtocolMessageType('GrantEntity', (_message.Message,), {
  'DESCRIPTOR' : _GRANTENTITY,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.GrantEntity)
  })
_sym_db.RegisterMessage(GrantEntity)

SelectGrantRequest = _reflection.GeneratedProtocolMessageType('SelectGrantRequest', (_message.Message,), {
  'DESCRIPTOR' : _SELECTGRANTREQUEST,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.SelectGrantRequest)
  })
_sym_db.RegisterMessage(SelectGrantRequest)

SelectGrantResponse = _reflection.GeneratedProtocolMessageType('SelectGrantResponse', (_message.Message,), {
  'DESCRIPTOR' : _SELECTGRANTRESPONSE,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.SelectGrantResponse)
  })
_sym_db.RegisterMessage(SelectGrantResponse)

OperatePrivilegeRequest = _reflection.GeneratedProtocolMessageType('OperatePrivilegeRequest', (_message.Message,), {
  'DESCRIPTOR' : _OPERATEPRIVILEGEREQUEST,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.OperatePrivilegeRequest)
  })
_sym_db.RegisterMessage(OperatePrivilegeRequest)

MilvusExt = _reflection.GeneratedProtocolMessageType('MilvusExt', (_message.Message,), {
  'DESCRIPTOR' : _MILVUSEXT,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.MilvusExt)
  })
_sym_db.RegisterMessage(MilvusExt)

_MILVUSSERVICE = DESCRIPTOR.services_by_name['MilvusService']
_PROXYSERVICE = DESCRIPTOR.services_by_name['ProxyService']
if _descriptor._USE_C_DESCRIPTORS == False:
  google_dot_protobuf_dot_descriptor__pb2.FileOptions.RegisterExtension(milvus_ext_obj)

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\016io.milvus.grpcB\013MilvusProtoP\001Z3github.com/milvus-io/milvus/internal/proto/milvuspb\240\001\001\312>\007\n\0052.1.0'
  _CREATECOLLECTIONREQUEST._options = None
  _CREATECOLLECTIONREQUEST._serialized_options = b'\312>\004\020\001\030\003'
  _DROPCOLLECTIONREQUEST._options = None
  _DROPCOLLECTIONREQUEST._serialized_options = b'\312>\004\020\002\030\003'
  _HASCOLLECTIONREQUEST._options = None
  _HASCOLLECTIONREQUEST._serialized_options = b'\312>\004\020\004\030\003'
  _DESCRIBECOLLECTIONREQUEST._options = None
  _DESCRIBECOLLECTIONREQUEST._serialized_options = b'\312>\004\020\004\030\003'
  _LOADCOLLECTIONREQUEST._options = None
  _LOADCOLLECTIONREQUEST._serialized_options = b'\312>\004\020\005\030\003'
  _RELEASECOLLECTIONREQUEST._options = None
  _RELEASECOLLECTIONREQUEST._serialized_options = b'\312>\004\020\006\030\003'
  _GETCOLLECTIONSTATISTICSREQUEST._options = None
  _GETCOLLECTIONSTATISTICSREQUEST._serialized_options = b'\312>\004\020\004\030\003'
  _SHOWCOLLECTIONSREQUEST._options = None
  _SHOWCOLLECTIONSREQUEST._serialized_options = b'\312>\002\020\004'
  _FLUSHRESPONSE_COLLSEGIDSENTRY._options = None
  _FLUSHRESPONSE_COLLSEGIDSENTRY._serialized_options = b'8\001'
  _SHOWTYPE._serialized_start=15089
  _SHOWTYPE._serialized_end=15122
  _OPERATEUSERROLETYPE._serialized_start=15124
  _OPERATEUSERROLETYPE._serialized_end=15188
  _OPERATEPRIVILEGETYPE._serialized_start=15190
  _OPERATEPRIVILEGETYPE._serialized_end=15235
  _CREATEALIASREQUEST._serialized_start=99
  _CREATEALIASREQUEST._serialized_end=220
  _DROPALIASREQUEST._serialized_start=222
  _DROPALIASREQUEST._serialized_end=316
  _ALTERALIASREQUEST._serialized_start=318
  _ALTERALIASREQUEST._serialized_end=438
  _CREATECOLLECTIONREQUEST._serialized_start=441
  _CREATECOLLECTIONREQUEST._serialized_end=663
  _DROPCOLLECTIONREQUEST._serialized_start=665
  _DROPCOLLECTIONREQUEST._serialized_end=783
  _HASCOLLECTIONREQUEST._serialized_start=786
  _HASCOLLECTIONREQUEST._serialized_end=923
  _BOOLRESPONSE._serialized_start=925
  _BOOLRESPONSE._serialized_end=999
  _STRINGRESPONSE._serialized_start=1001
  _STRINGRESPONSE._serialized_end=1077
  _DESCRIBECOLLECTIONREQUEST._serialized_start=1080
  _DESCRIBECOLLECTIONREQUEST._serialized_end=1244
  _DESCRIBECOLLECTIONRESPONSE._serialized_start=1247
  _DESCRIBECOLLECTIONRESPONSE._serialized_end=1705
  _LOADCOLLECTIONREQUEST._serialized_start=1708
  _LOADCOLLECTIONREQUEST._serialized_end=1850
  _RELEASECOLLECTIONREQUEST._serialized_start=1852
  _RELEASECOLLECTIONREQUEST._serialized_end=1973
  _GETCOLLECTIONSTATISTICSREQUEST._serialized_start=1975
  _GETCOLLECTIONSTATISTICSREQUEST._serialized_end=2102
  _GETCOLLECTIONSTATISTICSRESPONSE._serialized_start=2105
  _GETCOLLECTIONSTATISTICSRESPONSE._serialized_end=2233
  _SHOWCOLLECTIONSREQUEST._serialized_start=2236
  _SHOWCOLLECTIONSREQUEST._serialized_end=2419
  _SHOWCOLLECTIONSRESPONSE._serialized_start=2422
  _SHOWCOLLECTIONSRESPONSE._serialized_end=2665
  _CREATEPARTITIONREQUEST._serialized_start=2668
  _CREATEPARTITIONREQUEST._serialized_end=2802
  _DROPPARTITIONREQUEST._serialized_start=2805
  _DROPPARTITIONREQUEST._serialized_end=2937
  _HASPARTITIONREQUEST._serialized_start=2940
  _HASPARTITIONREQUEST._serialized_end=3071
  _LOADPARTITIONSREQUEST._serialized_start=3074
  _LOADPARTITIONSREQUEST._serialized_end=3232
  _RELEASEPARTITIONSREQUEST._serialized_start=3235
  _RELEASEPARTITIONSREQUEST._serialized_end=3372
  _GETPARTITIONSTATISTICSREQUEST._serialized_start=3375
  _GETPARTITIONSTATISTICSREQUEST._serialized_end=3516
  _GETPARTITIONSTATISTICSRESPONSE._serialized_start=3518
  _GETPARTITIONSTATISTICSRESPONSE._serialized_end=3645
  _SHOWPARTITIONSREQUEST._serialized_start=3648
  _SHOWPARTITIONSREQUEST._serialized_end=3849
  _SHOWPARTITIONSRESPONSE._serialized_start=3852
  _SHOWPARTITIONSRESPONSE._serialized_end=4058
  _DESCRIBESEGMENTREQUEST._serialized_start=4060
  _DESCRIBESEGMENTREQUEST._serialized_end=4169
  _DESCRIBESEGMENTRESPONSE._serialized_start=4172
  _DESCRIBESEGMENTRESPONSE._serialized_end=4315
  _SHOWSEGMENTSREQUEST._serialized_start=4317
  _SHOWSEGMENTSREQUEST._serialized_end=4425
  _SHOWSEGMENTSRESPONSE._serialized_start=4427
  _SHOWSEGMENTSRESPONSE._serialized_end=4514
  _CREATEINDEXREQUEST._serialized_start=4517
  _CREATEINDEXREQUEST._serialized_end=4720
  _DESCRIBEINDEXREQUEST._serialized_start=4723
  _DESCRIBEINDEXREQUEST._serialized_end=4871
  _INDEXDESCRIPTION._serialized_start=4873
  _INDEXDESCRIPTION._serialized_end=4999
  _DESCRIBEINDEXRESPONSE._serialized_start=5002
  _DESCRIBEINDEXRESPONSE._serialized_end=5137
  _GETINDEXBUILDPROGRESSREQUEST._serialized_start=5140
  _GETINDEXBUILDPROGRESSREQUEST._serialized_end=5296
  _GETINDEXBUILDPROGRESSRESPONSE._serialized_start=5298
  _GETINDEXBUILDPROGRESSRESPONSE._serialized_end=5416
  _GETINDEXSTATEREQUEST._serialized_start=5419
  _GETINDEXSTATEREQUEST._serialized_end=5567
  _GETINDEXSTATERESPONSE._serialized_start=5570
  _GETINDEXSTATERESPONSE._serialized_end=5707
  _DROPINDEXREQUEST._serialized_start=5710
  _DROPINDEXREQUEST._serialized_end=5854
  _INSERTREQUEST._serialized_start=5857
  _INSERTREQUEST._serialized_end=6072
  _MUTATIONRESULT._serialized_start=6075
  _MUTATIONRESULT._serialized_end=6315
  _DELETEREQUEST._serialized_start=6318
  _DELETEREQUEST._serialized_end=6476
  _SEARCHREQUEST._serialized_start=6479
  _SEARCHREQUEST._serialized_end=6841
  _HITS._serialized_start=6843
  _HITS._serialized_end=6896
  _SEARCHRESULTS._serialized_start=6899
  _SEARCHRESULTS._serialized_end=7040
  _FLUSHREQUEST._serialized_start=7042
  _FLUSHREQUEST._serialized_end=7143
  _FLUSHRESPONSE._serialized_start=7146
  _FLUSHRESPONSE._serialized_end=7379
  _FLUSHRESPONSE_COLLSEGIDSENTRY._serialized_start=7298
  _FLUSHRESPONSE_COLLSEGIDSENTRY._serialized_end=7379
  _QUERYREQUEST._serialized_start=7382
  _QUERYREQUEST._serialized_end=7599
  _QUERYRESULTS._serialized_start=7602
  _QUERYRESULTS._serialized_end=7739
  _VECTORIDS._serialized_start=7741
  _VECTORIDS._serialized_end=7866
  _VECTORSARRAY._serialized_start=7869
  _VECTORSARRAY._serialized_end=8000
  _CALCDISTANCEREQUEST._serialized_start=8003
  _CALCDISTANCEREQUEST._serialized_end=8224
  _CALCDISTANCERESULTS._serialized_start=8227
  _CALCDISTANCERESULTS._serialized_end=8408
  _PERSISTENTSEGMENTINFO._serialized_start=8411
  _PERSISTENTSEGMENTINFO._serialized_end=8564
  _GETPERSISTENTSEGMENTINFOREQUEST._serialized_start=8566
  _GETPERSISTENTSEGMENTINFOREQUEST._serialized_end=8683
  _GETPERSISTENTSEGMENTINFORESPONSE._serialized_start=8686
  _GETPERSISTENTSEGMENTINFORESPONSE._serialized_end=8824
  _QUERYSEGMENTINFO._serialized_start=8827
  _QUERYSEGMENTINFO._serialized_end=9063
  _GETQUERYSEGMENTINFOREQUEST._serialized_start=9065
  _GETQUERYSEGMENTINFOREQUEST._serialized_end=9177
  _GETQUERYSEGMENTINFORESPONSE._serialized_start=9180
  _GETQUERYSEGMENTINFORESPONSE._serialized_end=9308
  _DUMMYREQUEST._serialized_start=9310
  _DUMMYREQUEST._serialized_end=9346
  _DUMMYRESPONSE._serialized_start=9348
  _DUMMYRESPONSE._serialized_end=9381
  _REGISTERLINKREQUEST._serialized_start=9383
  _REGISTERLINKREQUEST._serialized_end=9404
  _REGISTERLINKRESPONSE._serialized_start=9406
  _REGISTERLINKRESPONSE._serialized_end=9520
  _GETMETRICSREQUEST._serialized_start=9522
  _GETMETRICSREQUEST._serialized_end=9602
  _GETMETRICSRESPONSE._serialized_start=9604
  _GETMETRICSRESPONSE._serialized_end=9711
  _LOADBALANCEREQUEST._serialized_start=9714
  _LOADBALANCEREQUEST._serialized_end=9870
  _MANUALCOMPACTIONREQUEST._serialized_start=9872
  _MANUALCOMPACTIONREQUEST._serialized_end=9939
  _MANUALCOMPACTIONRESPONSE._serialized_start=9941
  _MANUALCOMPACTIONRESPONSE._serialized_end=10034
  _GETCOMPACTIONSTATEREQUEST._serialized_start=10036
  _GETCOMPACTIONSTATEREQUEST._serialized_end=10085
  _GETCOMPACTIONSTATERESPONSE._serialized_start=10088
  _GETCOMPACTIONSTATERESPONSE._serialized_end=10287
  _GETCOMPACTIONPLANSREQUEST._serialized_start=10289
  _GETCOMPACTIONPLANSREQUEST._serialized_end=10338
  _GETCOMPACTIONPLANSRESPONSE._serialized_start=10341
  _GETCOMPACTIONPLANSRESPONSE._serialized_end=10529
  _COMPACTIONMERGEINFO._serialized_start=10531
  _COMPACTIONMERGEINFO._serialized_end=10585
  _GETFLUSHSTATEREQUEST._serialized_start=10587
  _GETFLUSHSTATEREQUEST._serialized_end=10629
  _GETFLUSHSTATERESPONSE._serialized_start=10631
  _GETFLUSHSTATERESPONSE._serialized_end=10716
  _IMPORTREQUEST._serialized_start=10719
  _IMPORTREQUEST._serialized_end=10892
  _IMPORTRESPONSE._serialized_start=10894
  _IMPORTRESPONSE._serialized_end=10970
  _GETIMPORTSTATEREQUEST._serialized_start=10972
  _GETIMPORTSTATEREQUEST._serialized_end=11009
  _GETIMPORTSTATERESPONSE._serialized_start=11012
  _GETIMPORTSTATERESPONSE._serialized_end=11274
  _LISTIMPORTTASKSREQUEST._serialized_start=11276
  _LISTIMPORTTASKSREQUEST._serialized_end=11300
  _LISTIMPORTTASKSRESPONSE._serialized_start=11303
  _LISTIMPORTTASKSRESPONSE._serialized_end=11433
  _GETREPLICASREQUEST._serialized_start=11435
  _GETREPLICASREQUEST._serialized_end=11547
  _GETREPLICASRESPONSE._serialized_start=11549
  _GETREPLICASRESPONSE._serialized_end=11667
  _REPLICAINFO._serialized_start=11670
  _REPLICAINFO._serialized_end=11824
  _SHARDREPLICA._serialized_start=11826
  _SHARDREPLICA._serialized_end=11922
  _CREATECREDENTIALREQUEST._serialized_start=11925
  _CREATECREDENTIALREQUEST._serialized_end=12095
  _UPDATECREDENTIALREQUEST._serialized_start=12098
  _UPDATECREDENTIALREQUEST._serialized_end=12292
  _DELETECREDENTIALREQUEST._serialized_start=12294
  _DELETECREDENTIALREQUEST._serialized_end=12381
  _LISTCREDUSERSRESPONSE._serialized_start=12383
  _LISTCREDUSERSRESPONSE._serialized_end=12470
  _LISTCREDUSERSREQUEST._serialized_start=12472
  _LISTCREDUSERSREQUEST._serialized_end=12538
  _ROLEENTITY._serialized_start=12540
  _ROLEENTITY._serialized_end=12566
  _USERENTITY._serialized_start=12568
  _USERENTITY._serialized_end=12594
  _CREATEROLEREQUEST._serialized_start=12596
  _CREATEROLEREQUEST._serialized_end=12708
  _DROPROLEREQUEST._serialized_start=12710
  _DROPROLEREQUEST._serialized_end=12790
  _OPERATEUSERROLEREQUEST._serialized_start=12793
  _OPERATEUSERROLEREQUEST._serialized_end=12954
  _SELECTROLEREQUEST._serialized_start=12957
  _SELECTROLEREQUEST._serialized_end=13094
  _ROLERESULT._serialized_start=13096
  _ROLERESULT._serialized_end=13203
  _SELECTROLERESPONSE._serialized_start=13205
  _SELECTROLERESPONSE._serialized_end=13320
  _SELECTUSERREQUEST._serialized_start=13323
  _SELECTUSERREQUEST._serialized_end=13460
  _USERRESULT._serialized_start=13462
  _USERRESULT._serialized_end=13569
  _SELECTUSERRESPONSE._serialized_start=13571
  _SELECTUSERRESPONSE._serialized_end=13685
  _RESOURCEENTITY._serialized_start=13687
  _RESOURCEENTITY._serialized_end=13717
  _PRIVILEGEENTITY._serialized_start=13719
  _PRIVILEGEENTITY._serialized_end=13750
  _SELECTRESOURCEREQUEST._serialized_start=13753
  _SELECTRESOURCEREQUEST._serialized_end=13905
  _RESOURCERESULT._serialized_start=13908
  _RESOURCERESULT._serialized_end=14037
  _SELECTRESOURCERESPONSE._serialized_start=14039
  _SELECTRESOURCERESPONSE._serialized_end=14162
  _PRINCIPALENTITY._serialized_start=14165
  _PRINCIPALENTITY._serialized_end=14317
  _GRANTORENTITY._serialized_start=14319
  _GRANTORENTITY._serialized_end=14438
  _GRANTENTITY._serialized_start=14441
  _GRANTENTITY._serialized_end=14642
  _SELECTGRANTREQUEST._serialized_start=14644
  _SELECTGRANTREQUEST._serialized_end=14758
  _SELECTGRANTRESPONSE._serialized_start=14760
  _SELECTGRANTRESPONSE._serialized_end=14878
  _OPERATEPRIVILEGEREQUEST._serialized_start=14881
  _OPERATEPRIVILEGEREQUEST._serialized_end=15057
  _MILVUSEXT._serialized_start=15059
  _MILVUSEXT._serialized_end=15087
  _MILVUSSERVICE._serialized_start=15238
  _MILVUSSERVICE._serialized_end=20775
  _PROXYSERVICE._serialized_start=20777
  _PROXYSERVICE._serialized_end=20894
# @@protoc_insertion_point(module_scope)



# Copyright (C) 2019-2021 Zilliz. All rights reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
# in compliance with the License. You may obtain a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software distributed under the License
# is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
# or implied. See the License for the specific language governing permissions and limitations under
# the License.


class ParamError(ValueError):
    """
    Param of interface is illegal
    """


class ResultError(ValueError):
    """
    Result of interface is illegal
    """


class ConnectError(ValueError):
    """
    Connect server failed
    """


class NotConnectError(ConnectError):
    """
    Disconnect error
    """


class RepeatingConnectError(ConnectError):
    """
    Try to connect repeatedly
    """


class ConnectionPoolError(ConnectError):
    """
    Waiting timeout error
    """


class FutureTimeoutError(TimeoutError):
    """
    Future timeout
    """


class DeprecatedError(AttributeError):
    """
    Deprecated
    """


class VersionError(AttributeError):
    """
    Version not match
    """


class MilvusException(Exception):

    def __init__(self, code=-1, message=""):
        super(MilvusException, self).__init__(message)
        self._code = code
        self._message = message

    @property
    def code(self):
        return self._code

    @property
    def message(self):
        return self._message

    def __str__(self):
        return f"<{type(self).__name__}: (code={self._code}, message={self._message})>"


class MilvusUnavailableException(MilvusException):
    pass


class CollectionExistException(MilvusException):
    pass


class CollectionNotExistException(MilvusException):
    pass


class InvalidDimensionException(MilvusException):
    pass


class InvalidMetricTypeException(MilvusException):
    pass


class IllegalCollectionNameException(MilvusException):
    pass


class DescribeCollectionException(MilvusException):
    pass


class PartitionNotExistException(MilvusException):
    pass


class PartitionAlreadyExistException(MilvusException):
    pass


class InvalidArgumentException(MilvusException):
    pass


class IndexConflictException(MilvusException):
    pass


class IndexNotExistException(MilvusException):
    pass


class CannotInferSchemaException(MilvusException):
    pass


class SchemaNotReadyException(MilvusException):
    pass


class DataTypeNotMatchException(MilvusException):
    pass


class DataTypeNotSupportException(MilvusException):
    pass


class DataNotMatchException(MilvusException):
    pass


class ConnectionNotExistException(MilvusException):
    pass


class ConnectionConfigException(MilvusException):
    pass


class PrimaryKeyException(MilvusException):
    pass


class FieldsTypeException(MilvusException):
    pass


class FieldTypeException(MilvusException):
    pass


class AutoIDException(MilvusException):
    pass


class InvalidConsistencyLevel(MilvusException):
    pass


class ExceptionsMessage:
    NoHostPort = "connection configuration must contain 'host' and 'port'."
    HostType = "Type of 'host' must be str."
    PortType = "Type of 'port' must be str or int."
    ConnDiffConf = "Alias of %r already creating connections, but the configure is not the same as passed in."
    AliasType = "Alias should be string, but %r is given."
    ConnLackConf = "You need to pass in the configuration of the connection named %r ."
    ConnectFirst = "should create connect first."
    CollectionNotExistNoSchema = "Collection %r not exist, or you can pass in schema to create one."
    NoSchema = "Should be passed into the schema."
    EmptySchema = "The field of the schema cannot be empty."
    SchemaType = "Schema type must be schema.CollectionSchema."
    SchemaInconsistent = "The collection already exist, but the schema is not the same as the schema passed in."
    AutoIDWithData = "Auto_id is True, primary field should not have data."
    AutoIDType = "Param auto_id must be bool type."
    AutoIDInconsistent = "The auto_id of the collection is inconsistent with the auto_id of the primary key field."
    AutoIDIllegalRanges = "The auto-generated id ranges should be pairs."
    ConsistencyLevelInconsistent = "The collection already exist, but the consistency_level is not the same as the parameter passed in."
    AutoIDOnlyOnPK = "The auto_id can only be specified on the primary key field"
    AutoIDFieldType = "The auto_id can only be specified on field with DataType.INT64"
    FieldsNumInconsistent = "The data fields number is not match with schema."
    NoVector = "No vector field is found."
    NoneDataFrame = "Dataframe can not be None."
    DataFrameType = "Data type must be pandas.DataFrame."
    NoPrimaryKey = "Schema must have a primary key field."
    PrimaryKeyNotExist = "Primary field must in dataframe."
    PrimaryKeyOnlyOne = "Primary key field can only be one."
    PrimaryKeyType = "Primary key type must be DataType.INT64."
    IsPrimaryType = "Param is_primary must be bool type."
    DataTypeInconsistent = "The data in the same column must be of the same type."
    DataTypeNotSupport = "Data type is not support."
    DataLengthsInconsistent = "Arrays must all be same length."
    DataFrameInvalid = "Cannot infer schema from empty dataframe."
    NdArrayNotSupport = "Data type not support numpy.ndarray."
    TypeOfDataAndSchemaInconsistent = "The types of schema and data do not match."
    PartitionAlreadyExist = "Partition already exist."
    PartitionNotExist = "Partition not exist."
    IndexNotExist = "Index doesn't exist."
    CollectionType = "The type of collection must be pymilvus.Collection."
    FieldsType = "The fields of schema must be type list."
    FieldType = "The field of schema type must be FieldSchema."
    FieldDtype = "Field dtype must be of DataType"
    ExprType = "The type of expr must be string ,but %r is given."



from pymilvus import (
    connections,
    list_collections,
    FieldSchema, CollectionSchema, DataType,
    Collection, Index
)

# configure milvus hostname and port
print(f"\nCreate connection...")
connections.connect()

# List all collection names
print(f"\nList collections...")
print(list_collections())

# Create a collection named 'demo_film_tutorial'
print(f"\nCreate collection...")
field1 = FieldSchema(name="release_year", dtype=DataType.INT64, description="int64", is_primary=True)
field2 = FieldSchema(name="embedding", dtype=DataType.FLOAT_VECTOR, description="float vector", dim=128, is_primary=False)
schema = CollectionSchema(fields=[field1, field2], description="collection description")
collection = Collection(name='demo_film_tutorial', data=None, schema=schema)

print(f"\nCreate index...")
index_params = {"index_type": "IVF_FLAT", "metric_type": "L2", "params": {"nlist": 100}}
index = Index(collection, "embedding", index_params)
print(index.params)

print([index.params for index in collection.indexes])

print(f"\nDrop index...")
index.drop()

print([index.params for index in collection.indexes])
collection.drop()



import random
import sys
import math
import time
import numpy as np

from pymilvus import Milvus, DataType

# This example shows how to use milvus to calculate vectors distance

_HOST = '127.0.0.1'
_PORT = '19530'

# Create milvus client instance
milvus = Milvus(_HOST, _PORT)

_PRECISION = 1e-3


def gen_float_vectors(num, dim):
    vec_list = [[random.random() for _ in range(dim)] for _ in range(num)]
    return vec_list


def gen_binary_vectors(num, dim):
    zero_fill = 0
    if dim % 8 > 0:
        zero_fill = 8 - dim % 8
    binary_vectors = []
    raw_vectors = []
    for i in range(num):
        raw_vector = [random.randint(0, 1) for i in range(dim)]
        for k in range(zero_fill):
            raw_vector.append(0)
        raw_vectors.append(raw_vector)
        binary_vectors.append(bytes(np.packbits(raw_vector, axis=-1).tolist()))
    return binary_vectors, raw_vectors


def l2_distance(vec_l, vec_r, sqrt=False):
    if len(vec_l) != len(vec_r):
        return -1.0

    dist = 0.0
    for i in range(len(vec_l)):
        dist = dist + math.pow(vec_l[i] - vec_r[i], 2)
    if sqrt:
        dist = math.sqrt(dist)
    return dist


def ip_distance(vec_l, vec_r):
    if len(vec_l) != len(vec_r):
        return -1.0

    dist = 0.0
    for i in range(len(vec_l)):
        dist = dist + vec_l[i] * vec_r[i]
    return dist


def calc_float_distance(l_count, r_count, dim, metric):
    vectors_l = gen_float_vectors(l_count, dim)
    vectors_r = gen_float_vectors(r_count, dim)

    op_l = {"float_vectors": vectors_l}
    op_r = {"float_vectors": vectors_r}

    sqrt = True
    params = {"metric_type": metric, "sqrt": sqrt}
    time_start = time.time()
    results = milvus.calc_distance(vectors_left=op_l, vectors_right=op_r, params=params)
    time_end = time.time()
    print(f"{metric} distance(l_count {l_count}, r_count {r_count},  dim {dim}), time cost {(time_end-time_start)*1000} ms")
    print(f"The top 3 result: {results[:3]}")
    if len(results) != l_count * r_count:
        print("Incorrect results returned by calc_distance()")

    all_correct = True
    for i in range(l_count):
        vec_l = vectors_l[i]
        for j in range(r_count):
            vec_r = vectors_r[j]
            dist_1 = l2_distance(vec_l, vec_r, sqrt) if metric == "L2" else ip_distance(vec_l, vec_r)
            dist_2 = results[i * r_count + j]
            if math.fabs(dist_1 - dist_2) > _PRECISION:
                print("Incorrect result", dist_1, "vs", dist_2)
                all_correct = False

    if all_correct:
        print("All distance are correct\n")


def hamming_distance(vec_l, vec_r):
    if len(vec_l) != len(vec_r):
        return -1

    hamming = 0
    for i in range(len(vec_l)):
        if vec_l[i] != vec_r[i]:
            hamming = hamming + 1
    return hamming


def tanimoto_distance(vec_l, vec_r, dim):
    if len(vec_l) != len(vec_r):
        return -1

    hamming = hamming_distance(vec_l, vec_r)
    same_bits = dim - hamming
    return same_bits / (dim * 2 - same_bits)


def calc_binary_distance(l_count, r_count, dim, metric):
    vectors_l, raw_l = gen_binary_vectors(l_count, dim)
    vectors_r, raw_r = gen_binary_vectors(r_count, dim)

    op_l = {"bin_vectors": vectors_l}
    op_r = {"bin_vectors": vectors_r}

    params = {"metric_type": metric, "dim": dim}
    time_start = time.time()
    results = milvus.calc_distance(vectors_left=op_l, vectors_right=op_r, params=params)
    time_end = time.time()
    print(f"{metric} distance(l_count {l_count}, r_count {r_count},  dim {dim}), time cost {(time_end-time_start)*1000} ms")
    print(f"The top 3 result: {results[:3]}")
    if len(results) != l_count * r_count:
        print("Incorrect results returned by calc_distance()")

    all_correct = True
    for i in range(l_count):
        vec_l = raw_l[i]
        for j in range(r_count):
            vec_r = raw_r[j]
            dist_1 = hamming_distance(vec_l, vec_r) if metric == "HAMMING" else tanimoto_distance(vec_l, vec_r, dim)
            dist_2 = results[i * r_count + j]
            if math.fabs(dist_1 - dist_2) > _PRECISION:
                print("Incorrect result", dist_1, "vs", dist_2)
                all_correct = False

    if all_correct:
        print("All distance are correct\n")


def input_vectors_to_calc():
    calc_float_distance(100, 50, 256, "L2")
    calc_float_distance(5, 1000, 256, "IP")

    calc_binary_distance(10, 20, 99, "HAMMING")
    calc_binary_distance(5, 100, 1, "HAMMING")
    calc_binary_distance(100, 15, 16, "HAMMING")
    calc_binary_distance(10, 10, 7, "TANIMOTO")
    calc_binary_distance(500, 5, 1, "TANIMOTO")
    calc_binary_distance(50, 150, 16, "TANIMOTO")


def create_collection(collection, vec_field, dim):
    id_field = {
        "name": "id",
        "type": DataType.INT64,
        "auto_id": True,
        "is_primary": True,
    }
    vector_field = {
        "name": vec_field,
        "type": DataType.FLOAT_VECTOR,
        "params": {"dim": dim},
    }
    fields = {"fields": [id_field, vector_field]}

    milvus.create_collection(collection_name=collection, fields=fields)
    print("collection created:", collection)


def drop_collection(collection):
    if milvus.has_collection(collection):
        milvus.drop_collection(collection)
        print("collection dropped:", collection)


def insert(collection, vec_field, num, dim):
    vectors = [[random.random() for _ in range(dim)] for _ in range(num)]
    entities = [{"name": vec_field, "type": DataType.FLOAT_VECTOR, "values": vectors}]
    ids = milvus.insert(collection, entities)
    print("insert", len(list(ids._primary_keys)), "vectors into", collection)
    return list(ids._primary_keys), vectors


def flush(collection):
    milvus.flush([collection])
    print("collection flushed:", collection)


def load_collection(collection):
    milvus.load_collection(collection)
    print("collection loaded:", collection)


def insert_vectors_to_calc():
    collection_name = "test"
    vec_field = "vec"
    dim = 64
    drop_collection(collection_name)
    create_collection(collection_name, vec_field, dim)

    l_count = 10
    db_ids, db_vectors = insert(collection_name, vec_field, l_count, dim)
    flush(collection_name)
    load_collection(collection_name)

    r_count = 25
    vectors_r = gen_float_vectors(r_count, dim)

    op_l = {"ids": db_ids, "collection": collection_name, "field": vec_field}
    op_r = {"float_vectors": vectors_r}

    metric = "L2"
    sqrt = True
    params = {"metric_type": metric, "sqrt": sqrt}
    time_start = time.time()
    results = milvus.calc_distance(vectors_left=op_l, vectors_right=op_r, params=params)
    time_end = time.time()
    print(f"{metric} distance(l_count {l_count}, r_count {r_count},  dim {dim}), time cost {(time_end-time_start)*1000} ms")
    print(f"The top 3 result: {results[:3]}")
    if len(results) != l_count * r_count:
        print("Incorrect results returned by calc_distance()")

    all_correct = True
    for i in range(l_count):
        vec_l = db_vectors[i]
        for j in range(r_count):
            vec_r = vectors_r[j]
            dist_1 = l2_distance(vec_l, vec_r, sqrt) if metric == "L2" else ip_distance(vec_l, vec_r)
            dist_2 = results[i * r_count + j]
            if math.fabs(dist_1 - dist_2) > _PRECISION:
                print("Incorrect result", dist_1, "vs", dist_2)
                all_correct = False

    if all_correct:
        print("All distance are correct\n")


if __name__ == '__main__':
    input_vectors_to_calc()
    insert_vectors_to_calc()
